/* DataImportsPluginHost.c generated by valac 0.32.1, the Vala compiler
 * generated from DataImportsPluginHost.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */

#include <glib.h>
#include <glib-object.h>
#include "shotwell-plugin-dev-1.0.h"
#include <float.h>
#include <math.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <glib/gi18n-lib.h>
#include <gio/gio.h>
#include <gtk/gtk.h>
#include <time.h>
#include <gobject/gvaluecollector.h>


#define SPIT_DATA_IMPORTS_TYPE_CORE_IMPORTER (spit_data_imports_core_importer_get_type ())
#define SPIT_DATA_IMPORTS_CORE_IMPORTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPIT_DATA_IMPORTS_TYPE_CORE_IMPORTER, SpitDataImportsCoreImporter))
#define SPIT_DATA_IMPORTS_CORE_IMPORTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPIT_DATA_IMPORTS_TYPE_CORE_IMPORTER, SpitDataImportsCoreImporterClass))
#define SPIT_DATA_IMPORTS_IS_CORE_IMPORTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPIT_DATA_IMPORTS_TYPE_CORE_IMPORTER))
#define SPIT_DATA_IMPORTS_IS_CORE_IMPORTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPIT_DATA_IMPORTS_TYPE_CORE_IMPORTER))
#define SPIT_DATA_IMPORTS_CORE_IMPORTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPIT_DATA_IMPORTS_TYPE_CORE_IMPORTER, SpitDataImportsCoreImporterClass))

typedef struct _SpitDataImportsCoreImporter SpitDataImportsCoreImporter;
typedef struct _SpitDataImportsCoreImporterClass SpitDataImportsCoreImporterClass;
typedef struct _SpitDataImportsCoreImporterPrivate SpitDataImportsCoreImporterPrivate;

#define TYPE_BATCH_IMPORT_ROLL (batch_import_roll_get_type ())
#define BATCH_IMPORT_ROLL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BATCH_IMPORT_ROLL, BatchImportRoll))
#define BATCH_IMPORT_ROLL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BATCH_IMPORT_ROLL, BatchImportRollClass))
#define IS_BATCH_IMPORT_ROLL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BATCH_IMPORT_ROLL))
#define IS_BATCH_IMPORT_ROLL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BATCH_IMPORT_ROLL))
#define BATCH_IMPORT_ROLL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BATCH_IMPORT_ROLL, BatchImportRollClass))

typedef struct _BatchImportRoll BatchImportRoll;
typedef struct _BatchImportRollClass BatchImportRollClass;
#define _batch_import_roll_unref0(var) ((var == NULL) ? NULL : (var = (batch_import_roll_unref (var), NULL)))

#define TYPE_SORTED_LIST (sorted_list_get_type ())
#define SORTED_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SORTED_LIST, SortedList))
#define SORTED_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SORTED_LIST, SortedListClass))
#define IS_SORTED_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SORTED_LIST))
#define IS_SORTED_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SORTED_LIST))
#define SORTED_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SORTED_LIST, SortedListClass))

typedef struct _SortedList SortedList;
typedef struct _SortedListClass SortedListClass;

#define TYPE_BATCH_IMPORT_JOB (batch_import_job_get_type ())
#define BATCH_IMPORT_JOB(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BATCH_IMPORT_JOB, BatchImportJob))
#define BATCH_IMPORT_JOB_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BATCH_IMPORT_JOB, BatchImportJobClass))
#define IS_BATCH_IMPORT_JOB(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BATCH_IMPORT_JOB))
#define IS_BATCH_IMPORT_JOB_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BATCH_IMPORT_JOB))
#define BATCH_IMPORT_JOB_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BATCH_IMPORT_JOB, BatchImportJobClass))

typedef struct _BatchImportJob BatchImportJob;
typedef struct _BatchImportJobClass BatchImportJobClass;

#define SPIT_DATA_IMPORTS_TYPE_DATA_IMPORT_JOB (spit_data_imports_data_import_job_get_type ())
#define SPIT_DATA_IMPORTS_DATA_IMPORT_JOB(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPIT_DATA_IMPORTS_TYPE_DATA_IMPORT_JOB, SpitDataImportsDataImportJob))
#define SPIT_DATA_IMPORTS_DATA_IMPORT_JOB_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPIT_DATA_IMPORTS_TYPE_DATA_IMPORT_JOB, SpitDataImportsDataImportJobClass))
#define SPIT_DATA_IMPORTS_IS_DATA_IMPORT_JOB(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPIT_DATA_IMPORTS_TYPE_DATA_IMPORT_JOB))
#define SPIT_DATA_IMPORTS_IS_DATA_IMPORT_JOB_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPIT_DATA_IMPORTS_TYPE_DATA_IMPORT_JOB))
#define SPIT_DATA_IMPORTS_DATA_IMPORT_JOB_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPIT_DATA_IMPORTS_TYPE_DATA_IMPORT_JOB, SpitDataImportsDataImportJobClass))

typedef struct _SpitDataImportsDataImportJob SpitDataImportsDataImportJob;
typedef struct _SpitDataImportsDataImportJobClass SpitDataImportsDataImportJobClass;

#define SPIT_DATA_IMPORTS_TYPE_DATA_IMPORT_SOURCE (spit_data_imports_data_import_source_get_type ())
#define SPIT_DATA_IMPORTS_DATA_IMPORT_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPIT_DATA_IMPORTS_TYPE_DATA_IMPORT_SOURCE, SpitDataImportsDataImportSource))
#define SPIT_DATA_IMPORTS_DATA_IMPORT_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPIT_DATA_IMPORTS_TYPE_DATA_IMPORT_SOURCE, SpitDataImportsDataImportSourceClass))
#define SPIT_DATA_IMPORTS_IS_DATA_IMPORT_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPIT_DATA_IMPORTS_TYPE_DATA_IMPORT_SOURCE))
#define SPIT_DATA_IMPORTS_IS_DATA_IMPORT_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPIT_DATA_IMPORTS_TYPE_DATA_IMPORT_SOURCE))
#define SPIT_DATA_IMPORTS_DATA_IMPORT_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPIT_DATA_IMPORTS_TYPE_DATA_IMPORT_SOURCE, SpitDataImportsDataImportSourceClass))

typedef struct _SpitDataImportsDataImportSource SpitDataImportsDataImportSource;
typedef struct _SpitDataImportsDataImportSourceClass SpitDataImportsDataImportSourceClass;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _batch_import_job_unref0(var) ((var == NULL) ? NULL : (var = (batch_import_job_unref (var), NULL)))
#define _spit_data_imports_data_import_source_unref0(var) ((var == NULL) ? NULL : (var = (spit_data_imports_data_import_source_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TYPE_BATCH_IMPORT (batch_import_get_type ())
#define BATCH_IMPORT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BATCH_IMPORT, BatchImport))
#define BATCH_IMPORT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BATCH_IMPORT, BatchImportClass))
#define IS_BATCH_IMPORT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BATCH_IMPORT))
#define IS_BATCH_IMPORT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BATCH_IMPORT))
#define BATCH_IMPORT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BATCH_IMPORT, BatchImportClass))

typedef struct _BatchImport BatchImport;
typedef struct _BatchImportClass BatchImportClass;

#define TYPE_IMPORT_MANIFEST (import_manifest_get_type ())
#define IMPORT_MANIFEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_IMPORT_MANIFEST, ImportManifest))
#define IMPORT_MANIFEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_IMPORT_MANIFEST, ImportManifestClass))
#define IS_IMPORT_MANIFEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_IMPORT_MANIFEST))
#define IS_IMPORT_MANIFEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_IMPORT_MANIFEST))
#define IMPORT_MANIFEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_IMPORT_MANIFEST, ImportManifestClass))

typedef struct _ImportManifest ImportManifest;
typedef struct _ImportManifestClass ImportManifestClass;

#define TYPE_PAGE_WINDOW (page_window_get_type ())
#define PAGE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE_WINDOW, PageWindow))
#define PAGE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE_WINDOW, PageWindowClass))
#define IS_PAGE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE_WINDOW))
#define IS_PAGE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE_WINDOW))
#define PAGE_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE_WINDOW, PageWindowClass))

typedef struct _PageWindow PageWindow;
typedef struct _PageWindowClass PageWindowClass;

#define TYPE_APP_WINDOW (app_window_get_type ())
#define APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_APP_WINDOW, AppWindow))
#define APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_APP_WINDOW, AppWindowClass))
#define IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_APP_WINDOW))
#define IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_APP_WINDOW))
#define APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_APP_WINDOW, AppWindowClass))

typedef struct _AppWindow AppWindow;
typedef struct _AppWindowClass AppWindowClass;

#define TYPE_LIBRARY_WINDOW (library_window_get_type ())
#define LIBRARY_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LIBRARY_WINDOW, LibraryWindow))
#define LIBRARY_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LIBRARY_WINDOW, LibraryWindowClass))
#define IS_LIBRARY_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LIBRARY_WINDOW))
#define IS_LIBRARY_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LIBRARY_WINDOW))
#define LIBRARY_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LIBRARY_WINDOW, LibraryWindowClass))

typedef struct _LibraryWindow LibraryWindow;
typedef struct _LibraryWindowClass LibraryWindowClass;
typedef struct _SpitDataImportsParamSpecCoreImporter SpitDataImportsParamSpecCoreImporter;

#define PLUGINS_TYPE_STANDARD_HOST_INTERFACE (plugins_standard_host_interface_get_type ())
#define PLUGINS_STANDARD_HOST_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PLUGINS_TYPE_STANDARD_HOST_INTERFACE, PluginsStandardHostInterface))
#define PLUGINS_STANDARD_HOST_INTERFACE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PLUGINS_TYPE_STANDARD_HOST_INTERFACE, PluginsStandardHostInterfaceClass))
#define PLUGINS_IS_STANDARD_HOST_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PLUGINS_TYPE_STANDARD_HOST_INTERFACE))
#define PLUGINS_IS_STANDARD_HOST_INTERFACE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PLUGINS_TYPE_STANDARD_HOST_INTERFACE))
#define PLUGINS_STANDARD_HOST_INTERFACE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PLUGINS_TYPE_STANDARD_HOST_INTERFACE, PluginsStandardHostInterfaceClass))

typedef struct _PluginsStandardHostInterface PluginsStandardHostInterface;
typedef struct _PluginsStandardHostInterfaceClass PluginsStandardHostInterfaceClass;
typedef struct _PluginsStandardHostInterfacePrivate PluginsStandardHostInterfacePrivate;

#define SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST (spit_data_imports_concrete_data_imports_host_get_type ())
#define SPIT_DATA_IMPORTS_CONCRETE_DATA_IMPORTS_HOST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHost))
#define SPIT_DATA_IMPORTS_CONCRETE_DATA_IMPORTS_HOST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHostClass))
#define SPIT_DATA_IMPORTS_IS_CONCRETE_DATA_IMPORTS_HOST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST))
#define SPIT_DATA_IMPORTS_IS_CONCRETE_DATA_IMPORTS_HOST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST))
#define SPIT_DATA_IMPORTS_CONCRETE_DATA_IMPORTS_HOST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHostClass))

typedef struct _SpitDataImportsConcreteDataImportsHost SpitDataImportsConcreteDataImportsHost;
typedef struct _SpitDataImportsConcreteDataImportsHostClass SpitDataImportsConcreteDataImportsHostClass;
typedef struct _SpitDataImportsConcreteDataImportsHostPrivate SpitDataImportsConcreteDataImportsHostPrivate;

#define DATA_IMPORTS_UI_TYPE_DATA_IMPORTS_DIALOG (data_imports_ui_data_imports_dialog_get_type ())
#define DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_UI_TYPE_DATA_IMPORTS_DIALOG, DataImportsUIDataImportsDialog))
#define DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_UI_TYPE_DATA_IMPORTS_DIALOG, DataImportsUIDataImportsDialogClass))
#define DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_UI_TYPE_DATA_IMPORTS_DIALOG))
#define DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_UI_TYPE_DATA_IMPORTS_DIALOG))
#define DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_UI_TYPE_DATA_IMPORTS_DIALOG, DataImportsUIDataImportsDialogClass))

typedef struct _DataImportsUIDataImportsDialog DataImportsUIDataImportsDialog;
typedef struct _DataImportsUIDataImportsDialogClass DataImportsUIDataImportsDialogClass;

#define DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE (data_imports_ui_concrete_dialog_pane_get_type ())
#define DATA_IMPORTS_UI_CONCRETE_DIALOG_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE, DataImportsUIConcreteDialogPane))
#define DATA_IMPORTS_UI_CONCRETE_DIALOG_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE, DataImportsUIConcreteDialogPaneClass))
#define DATA_IMPORTS_UI_IS_CONCRETE_DIALOG_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE))
#define DATA_IMPORTS_UI_IS_CONCRETE_DIALOG_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE))
#define DATA_IMPORTS_UI_CONCRETE_DIALOG_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE, DataImportsUIConcreteDialogPaneClass))

typedef struct _DataImportsUIConcreteDialogPane DataImportsUIConcreteDialogPane;
typedef struct _DataImportsUIConcreteDialogPaneClass DataImportsUIConcreteDialogPaneClass;

#define DATA_IMPORTS_UI_TYPE_PROGRESS_PANE (data_imports_ui_progress_pane_get_type ())
#define DATA_IMPORTS_UI_PROGRESS_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_UI_TYPE_PROGRESS_PANE, DataImportsUIProgressPane))
#define DATA_IMPORTS_UI_PROGRESS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_UI_TYPE_PROGRESS_PANE, DataImportsUIProgressPaneClass))
#define DATA_IMPORTS_UI_IS_PROGRESS_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_UI_TYPE_PROGRESS_PANE))
#define DATA_IMPORTS_UI_IS_PROGRESS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_UI_TYPE_PROGRESS_PANE))
#define DATA_IMPORTS_UI_PROGRESS_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_UI_TYPE_PROGRESS_PANE, DataImportsUIProgressPaneClass))

typedef struct _DataImportsUIProgressPane DataImportsUIProgressPane;
typedef struct _DataImportsUIProgressPaneClass DataImportsUIProgressPaneClass;
#define _spit_data_imports_core_importer_unref0(var) ((var == NULL) ? NULL : (var = (spit_data_imports_core_importer_unref (var), NULL)))

#define DATA_IMPORTS_UI_TYPE_STATIC_MESSAGE_PANE (data_imports_ui_static_message_pane_get_type ())
#define DATA_IMPORTS_UI_STATIC_MESSAGE_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_UI_TYPE_STATIC_MESSAGE_PANE, DataImportsUIStaticMessagePane))
#define DATA_IMPORTS_UI_STATIC_MESSAGE_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_UI_TYPE_STATIC_MESSAGE_PANE, DataImportsUIStaticMessagePaneClass))
#define DATA_IMPORTS_UI_IS_STATIC_MESSAGE_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_UI_TYPE_STATIC_MESSAGE_PANE))
#define DATA_IMPORTS_UI_IS_STATIC_MESSAGE_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_UI_TYPE_STATIC_MESSAGE_PANE))
#define DATA_IMPORTS_UI_STATIC_MESSAGE_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_UI_TYPE_STATIC_MESSAGE_PANE, DataImportsUIStaticMessagePaneClass))

typedef struct _DataImportsUIStaticMessagePane DataImportsUIStaticMessagePane;
typedef struct _DataImportsUIStaticMessagePaneClass DataImportsUIStaticMessagePaneClass;

#define DATA_IMPORTS_UI_TYPE_LIBRARY_SELECTION_PANE (data_imports_ui_library_selection_pane_get_type ())
#define DATA_IMPORTS_UI_LIBRARY_SELECTION_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_UI_TYPE_LIBRARY_SELECTION_PANE, DataImportsUILibrarySelectionPane))
#define DATA_IMPORTS_UI_LIBRARY_SELECTION_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_UI_TYPE_LIBRARY_SELECTION_PANE, DataImportsUILibrarySelectionPaneClass))
#define DATA_IMPORTS_UI_IS_LIBRARY_SELECTION_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_UI_TYPE_LIBRARY_SELECTION_PANE))
#define DATA_IMPORTS_UI_IS_LIBRARY_SELECTION_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_UI_TYPE_LIBRARY_SELECTION_PANE))
#define DATA_IMPORTS_UI_LIBRARY_SELECTION_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_UI_TYPE_LIBRARY_SELECTION_PANE, DataImportsUILibrarySelectionPaneClass))

typedef struct _DataImportsUILibrarySelectionPane DataImportsUILibrarySelectionPane;
typedef struct _DataImportsUILibrarySelectionPaneClass DataImportsUILibrarySelectionPaneClass;

#define SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST (spit_data_imports_welcome_data_imports_host_get_type ())
#define SPIT_DATA_IMPORTS_WELCOME_DATA_IMPORTS_HOST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST, SpitDataImportsWelcomeDataImportsHost))
#define SPIT_DATA_IMPORTS_WELCOME_DATA_IMPORTS_HOST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST, SpitDataImportsWelcomeDataImportsHostClass))
#define SPIT_DATA_IMPORTS_IS_WELCOME_DATA_IMPORTS_HOST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST))
#define SPIT_DATA_IMPORTS_IS_WELCOME_DATA_IMPORTS_HOST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST))
#define SPIT_DATA_IMPORTS_WELCOME_DATA_IMPORTS_HOST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST, SpitDataImportsWelcomeDataImportsHostClass))

typedef struct _SpitDataImportsWelcomeDataImportsHost SpitDataImportsWelcomeDataImportsHost;
typedef struct _SpitDataImportsWelcomeDataImportsHostClass SpitDataImportsWelcomeDataImportsHostClass;
typedef struct _SpitDataImportsWelcomeDataImportsHostPrivate SpitDataImportsWelcomeDataImportsHostPrivate;

#define SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_META_HOST (spit_data_imports_welcome_import_meta_host_get_type ())
#define SPIT_DATA_IMPORTS_WELCOME_IMPORT_META_HOST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_META_HOST, SpitDataImportsWelcomeImportMetaHost))
#define SPIT_DATA_IMPORTS_WELCOME_IMPORT_META_HOST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_META_HOST, SpitDataImportsWelcomeImportMetaHostClass))
#define SPIT_DATA_IMPORTS_IS_WELCOME_IMPORT_META_HOST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_META_HOST))
#define SPIT_DATA_IMPORTS_IS_WELCOME_IMPORT_META_HOST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_META_HOST))
#define SPIT_DATA_IMPORTS_WELCOME_IMPORT_META_HOST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_META_HOST, SpitDataImportsWelcomeImportMetaHostClass))

typedef struct _SpitDataImportsWelcomeImportMetaHost SpitDataImportsWelcomeImportMetaHost;
typedef struct _SpitDataImportsWelcomeImportMetaHostClass SpitDataImportsWelcomeImportMetaHostClass;

#define TYPE_WELCOME_SERVICE_ENTRY (welcome_service_entry_get_type ())
#define WELCOME_SERVICE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_WELCOME_SERVICE_ENTRY, WelcomeServiceEntry))
#define IS_WELCOME_SERVICE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_WELCOME_SERVICE_ENTRY))
#define WELCOME_SERVICE_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_WELCOME_SERVICE_ENTRY, WelcomeServiceEntryIface))

typedef struct _WelcomeServiceEntry WelcomeServiceEntry;
typedef struct _WelcomeServiceEntryIface WelcomeServiceEntryIface;

#define SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_SERVICE_ENTRY (spit_data_imports_welcome_import_service_entry_get_type ())
#define SPIT_DATA_IMPORTS_WELCOME_IMPORT_SERVICE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_SERVICE_ENTRY, SpitDataImportsWelcomeImportServiceEntry))
#define SPIT_DATA_IMPORTS_WELCOME_IMPORT_SERVICE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_SERVICE_ENTRY, SpitDataImportsWelcomeImportServiceEntryClass))
#define SPIT_DATA_IMPORTS_IS_WELCOME_IMPORT_SERVICE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_SERVICE_ENTRY))
#define SPIT_DATA_IMPORTS_IS_WELCOME_IMPORT_SERVICE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_SERVICE_ENTRY))
#define SPIT_DATA_IMPORTS_WELCOME_IMPORT_SERVICE_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_SERVICE_ENTRY, SpitDataImportsWelcomeImportServiceEntryClass))

typedef struct _SpitDataImportsWelcomeImportServiceEntry SpitDataImportsWelcomeImportServiceEntry;
typedef struct _SpitDataImportsWelcomeImportServiceEntryClass SpitDataImportsWelcomeImportServiceEntryClass;
typedef struct _SpitDataImportsWelcomeImportServiceEntryPrivate SpitDataImportsWelcomeImportServiceEntryPrivate;
typedef struct _SpitDataImportsWelcomeImportMetaHostPrivate SpitDataImportsWelcomeImportMetaHostPrivate;

#define TYPE_WELCOME_DIALOG (welcome_dialog_get_type ())
#define WELCOME_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_WELCOME_DIALOG, WelcomeDialog))
#define WELCOME_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_WELCOME_DIALOG, WelcomeDialogClass))
#define IS_WELCOME_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_WELCOME_DIALOG))
#define IS_WELCOME_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_WELCOME_DIALOG))
#define WELCOME_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_WELCOME_DIALOG, WelcomeDialogClass))

typedef struct _WelcomeDialog WelcomeDialog;
typedef struct _WelcomeDialogClass WelcomeDialogClass;
typedef struct _ImportManifestPrivate ImportManifestPrivate;

#define TYPE_DATA_OBJECT (data_object_get_type ())
#define DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_OBJECT, DataObject))
#define DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_OBJECT, DataObjectClass))
#define IS_DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_OBJECT))
#define IS_DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_OBJECT))
#define DATA_OBJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_OBJECT, DataObjectClass))

typedef struct _DataObject DataObject;
typedef struct _DataObjectClass DataObjectClass;

#define TYPE_DATA_SOURCE (data_source_get_type ())
#define DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_SOURCE, DataSource))
#define DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_SOURCE, DataSourceClass))
#define IS_DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_SOURCE))
#define IS_DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_SOURCE))
#define DATA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_SOURCE, DataSourceClass))

typedef struct _DataSource DataSource;
typedef struct _DataSourceClass DataSourceClass;

#define TYPE_THUMBNAIL_SOURCE (thumbnail_source_get_type ())
#define THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSource))
#define THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))
#define IS_THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_THUMBNAIL_SOURCE))
#define IS_THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_THUMBNAIL_SOURCE))
#define THUMBNAIL_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))

typedef struct _ThumbnailSource ThumbnailSource;
typedef struct _ThumbnailSourceClass ThumbnailSourceClass;

#define TYPE_MEDIA_SOURCE (media_source_get_type ())
#define MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE, MediaSource))
#define MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE, MediaSourceClass))
#define IS_MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE))
#define IS_MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE))
#define MEDIA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE, MediaSourceClass))

typedef struct _MediaSource MediaSource;
typedef struct _MediaSourceClass MediaSourceClass;

#define TYPE_BATCH_IMPORT_RESULT (batch_import_result_get_type ())
#define BATCH_IMPORT_RESULT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BATCH_IMPORT_RESULT, BatchImportResult))
#define BATCH_IMPORT_RESULT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BATCH_IMPORT_RESULT, BatchImportResultClass))
#define IS_BATCH_IMPORT_RESULT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BATCH_IMPORT_RESULT))
#define IS_BATCH_IMPORT_RESULT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BATCH_IMPORT_RESULT))
#define BATCH_IMPORT_RESULT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BATCH_IMPORT_RESULT, BatchImportResultClass))

typedef struct _BatchImportResult BatchImportResult;
typedef struct _BatchImportResultClass BatchImportResultClass;
#define _import_manifest_unref0(var) ((var == NULL) ? NULL : (var = (import_manifest_unref (var), NULL)))
#define _batch_import_result_unref0(var) ((var == NULL) ? NULL : (var = (batch_import_result_unref (var), NULL)))

#define IMPORT_UI_TYPE_QUESTION_PARAMS (import_ui_question_params_get_type ())
#define IMPORT_UI_QUESTION_PARAMS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), IMPORT_UI_TYPE_QUESTION_PARAMS, ImportUIQuestionParams))
#define IMPORT_UI_QUESTION_PARAMS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), IMPORT_UI_TYPE_QUESTION_PARAMS, ImportUIQuestionParamsClass))
#define IMPORT_UI_IS_QUESTION_PARAMS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), IMPORT_UI_TYPE_QUESTION_PARAMS))
#define IMPORT_UI_IS_QUESTION_PARAMS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), IMPORT_UI_TYPE_QUESTION_PARAMS))
#define IMPORT_UI_QUESTION_PARAMS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), IMPORT_UI_TYPE_QUESTION_PARAMS, ImportUIQuestionParamsClass))

typedef struct _ImportUIQuestionParams ImportUIQuestionParams;
typedef struct _ImportUIQuestionParamsClass ImportUIQuestionParamsClass;

struct _SpitDataImportsCoreImporter {
	GTypeInstance parent_instance;
	volatile int ref_count;
	SpitDataImportsCoreImporterPrivate * priv;
	gint imported_items_count;
	BatchImportRoll* current_import_roll;
};

struct _SpitDataImportsCoreImporterClass {
	GTypeClass parent_class;
	void (*finalize) (SpitDataImportsCoreImporter *self);
};

struct _SpitDataImportsCoreImporterPrivate {
	SpitDataImportsPluginHost* host;
};

typedef gint64 (*Comparator) (void* a, void* b, void* user_data);
typedef void (*BatchImportImportReporter) (ImportManifest* manifest, BatchImportRoll* import_roll, void* user_data);
struct _SpitDataImportsParamSpecCoreImporter {
	GParamSpec parent_instance;
};

struct _PluginsStandardHostInterface {
	GObject parent_instance;
	PluginsStandardHostInterfacePrivate * priv;
};

struct _PluginsStandardHostInterfaceClass {
	GObjectClass parent_class;
};

struct _SpitDataImportsConcreteDataImportsHost {
	PluginsStandardHostInterface parent_instance;
	SpitDataImportsConcreteDataImportsHostPrivate * priv;
};

struct _SpitDataImportsConcreteDataImportsHostClass {
	PluginsStandardHostInterfaceClass parent_class;
};

struct _SpitDataImportsConcreteDataImportsHostPrivate {
	SpitDataImportsDataImporter* active_importer;
	DataImportsUIDataImportsDialog* dialog;
	DataImportsUIProgressPane* progress_pane;
	gboolean importing_halted;
	SpitDataImportsCoreImporter* core_importer;
};

struct _SpitDataImportsWelcomeDataImportsHost {
	PluginsStandardHostInterface parent_instance;
	SpitDataImportsWelcomeDataImportsHostPrivate * priv;
};

struct _SpitDataImportsWelcomeDataImportsHostClass {
	PluginsStandardHostInterfaceClass parent_class;
};

struct _SpitDataImportsWelcomeDataImportsHostPrivate {
	SpitDataImportsWelcomeImportMetaHost* meta_host;
	SpitDataImportsDataImporter* active_importer;
	gboolean importing_halted;
	SpitDataImportsCoreImporter* core_importer;
};

struct _WelcomeServiceEntryIface {
	GTypeInterface parent_iface;
	gchar* (*get_service_name) (WelcomeServiceEntry* self);
	void (*execute) (WelcomeServiceEntry* self);
};

struct _SpitDataImportsWelcomeImportServiceEntry {
	GObject parent_instance;
	SpitDataImportsWelcomeImportServiceEntryPrivate * priv;
};

struct _SpitDataImportsWelcomeImportServiceEntryClass {
	GObjectClass parent_class;
};

struct _SpitDataImportsWelcomeImportServiceEntryPrivate {
	gchar* pluggable_name;
	SpitDataImportsImportableLibrary** discovered_libraries;
	gint discovered_libraries_length1;
	gint _discovered_libraries_size_;
	SpitDataImportsPluginHost* host;
};

struct _SpitDataImportsWelcomeImportMetaHost {
	GObject parent_instance;
	SpitDataImportsWelcomeImportMetaHostPrivate * priv;
};

struct _SpitDataImportsWelcomeImportMetaHostClass {
	GObjectClass parent_class;
};

struct _SpitDataImportsWelcomeImportMetaHostPrivate {
	WelcomeDialog* dialog;
};

struct _ImportManifest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	ImportManifestPrivate * priv;
	GeeList* imported;
	GeeList* success;
	GeeList* camera_failed;
	GeeList* failed;
	GeeList* write_failed;
	GeeList* skipped_photos;
	GeeList* skipped_files;
	GeeList* aborted;
	GeeList* already_imported;
	GeeList* corrupt_files;
	GeeList* all;
};

struct _ImportManifestClass {
	GTypeClass parent_class;
	void (*finalize) (ImportManifest *self);
};


static gpointer spit_data_imports_core_importer_parent_class = NULL;
static gpointer spit_data_imports_concrete_data_imports_host_parent_class = NULL;
static SpitDataImportsPluginHostIface* spit_data_imports_concrete_data_imports_host_spit_data_imports_plugin_host_parent_iface = NULL;
static gpointer spit_data_imports_welcome_data_imports_host_parent_class = NULL;
static SpitDataImportsPluginHostIface* spit_data_imports_welcome_data_imports_host_spit_data_imports_plugin_host_parent_iface = NULL;
static gpointer spit_data_imports_welcome_import_service_entry_parent_class = NULL;
static WelcomeServiceEntryIface* spit_data_imports_welcome_import_service_entry_welcome_service_entry_parent_iface = NULL;
static gpointer spit_data_imports_welcome_import_meta_host_parent_class = NULL;
extern ImportManifest* spit_data_imports_meta_manifest;
ImportManifest* spit_data_imports_meta_manifest = NULL;

gpointer spit_data_imports_core_importer_ref (gpointer instance);
void spit_data_imports_core_importer_unref (gpointer instance);
GParamSpec* spit_data_imports_param_spec_core_importer (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void spit_data_imports_value_set_core_importer (GValue* value, gpointer v_object);
void spit_data_imports_value_take_core_importer (GValue* value, gpointer v_object);
gpointer spit_data_imports_value_get_core_importer (const GValue* value);
GType spit_data_imports_core_importer_get_type (void) G_GNUC_CONST;
gpointer batch_import_roll_ref (gpointer instance);
void batch_import_roll_unref (gpointer instance);
GParamSpec* param_spec_batch_import_roll (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_batch_import_roll (GValue* value, gpointer v_object);
void value_take_batch_import_roll (GValue* value, gpointer v_object);
gpointer value_get_batch_import_roll (const GValue* value);
GType batch_import_roll_get_type (void) G_GNUC_CONST;
#define SPIT_DATA_IMPORTS_CORE_IMPORTER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), SPIT_DATA_IMPORTS_TYPE_CORE_IMPORTER, SpitDataImportsCoreImporterPrivate))
enum  {
	SPIT_DATA_IMPORTS_CORE_IMPORTER_DUMMY_PROPERTY
};
SpitDataImportsCoreImporter* spit_data_imports_core_importer_new (SpitDataImportsPluginHost* host);
SpitDataImportsCoreImporter* spit_data_imports_core_importer_construct (GType object_type, SpitDataImportsPluginHost* host);
void spit_data_imports_core_importer_prepare_media_items_for_import (SpitDataImportsCoreImporter* self, SpitDataImportsImportableMediaItem** items, int items_length1, gdouble progress, gdouble host_progress_delta, const gchar* progress_message);
GType sorted_list_get_type (void) G_GNUC_CONST;
gpointer batch_import_job_ref (gpointer instance);
void batch_import_job_unref (gpointer instance);
GParamSpec* param_spec_batch_import_job (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_batch_import_job (GValue* value, gpointer v_object);
void value_take_batch_import_job (GValue* value, gpointer v_object);
gpointer value_get_batch_import_job (const GValue* value);
GType batch_import_job_get_type (void) G_GNUC_CONST;
GType spit_data_imports_data_import_job_get_type (void) G_GNUC_CONST;
gint64 spit_data_imports_import_job_comparator (void* a, void* b);
static gint64 _spit_data_imports_import_job_comparator_comparator (void* a, void* b, gpointer self);
SortedList* sorted_list_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, Comparator cmp, void* cmp_target);
SortedList* sorted_list_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, Comparator cmp, void* cmp_target);
gpointer spit_data_imports_data_import_source_ref (gpointer instance);
void spit_data_imports_data_import_source_unref (gpointer instance);
GParamSpec* spit_data_imports_param_spec_data_import_source (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void spit_data_imports_value_set_data_import_source (GValue* value, gpointer v_object);
void spit_data_imports_value_take_data_import_source (GValue* value, gpointer v_object);
gpointer spit_data_imports_value_get_data_import_source (const GValue* value);
GType spit_data_imports_data_import_source_get_type (void) G_GNUC_CONST;
SpitDataImportsDataImportSource* spit_data_imports_data_import_source_new (SpitDataImportsImportableMediaItem* db_photo);
SpitDataImportsDataImportSource* spit_data_imports_data_import_source_construct (GType object_type, SpitDataImportsImportableMediaItem* db_photo);
gboolean spit_data_imports_data_import_source_was_backing_file_found (SpitDataImportsDataImportSource* self);
gchar* spit_data_imports_data_import_source_get_filename (SpitDataImportsDataImportSource* self);
SpitDataImportsDataImportJob* spit_data_imports_data_import_job_new (SpitDataImportsDataImportSource* import_source);
SpitDataImportsDataImportJob* spit_data_imports_data_import_job_construct (GType object_type, SpitDataImportsDataImportSource* import_source);
gboolean spit_data_imports_data_import_source_is_already_imported (SpitDataImportsDataImportSource* self);
BatchImportRoll* batch_import_roll_new (void);
BatchImportRoll* batch_import_roll_construct (GType object_type);
GType batch_import_get_type (void) G_GNUC_CONST;
gpointer import_manifest_ref (gpointer instance);
void import_manifest_unref (gpointer instance);
GParamSpec* param_spec_import_manifest (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_import_manifest (GValue* value, gpointer v_object);
void value_take_import_manifest (GValue* value, gpointer v_object);
gpointer value_get_import_manifest (const GValue* value);
GType import_manifest_get_type (void) G_GNUC_CONST;
void spit_data_imports_data_import_reporter (ImportManifest* manifest, BatchImportRoll* import_roll);
static void _spit_data_imports_data_import_reporter_batch_import_import_reporter (ImportManifest* manifest, BatchImportRoll* import_roll, gpointer self);
BatchImport* batch_import_new (GeeIterable* jobs, const gchar* name, BatchImportImportReporter reporter, void* reporter_target, GeeArrayList* prefailed, GeeArrayList* pre_already_imported, GCancellable* cancellable, BatchImportRoll* import_roll, ImportManifest* skip_manifest);
BatchImport* batch_import_construct (GType object_type, GeeIterable* jobs, const gchar* name, BatchImportImportReporter reporter, void* reporter_target, GeeArrayList* prefailed, GeeArrayList* pre_already_imported, GCancellable* cancellable, BatchImportRoll* import_roll, ImportManifest* skip_manifest);
GType page_window_get_type (void) G_GNUC_CONST;
GType app_window_get_type (void) G_GNUC_CONST;
GType library_window_get_type (void) G_GNUC_CONST;
LibraryWindow* library_window_get_app (void);
void library_window_enqueue_batch_import (LibraryWindow* self, BatchImport* batch_import, gboolean allow_user_cancel);
void spit_data_imports_core_importer_finalize_import (SpitDataImportsCoreImporter* self);
static void spit_data_imports_core_importer_finalize (SpitDataImportsCoreImporter* obj);
GType plugins_standard_host_interface_get_type (void) G_GNUC_CONST;
GType spit_data_imports_concrete_data_imports_host_get_type (void) G_GNUC_CONST;
GType data_imports_ui_data_imports_dialog_get_type (void) G_GNUC_CONST;
GType data_imports_ui_concrete_dialog_pane_get_type (void) G_GNUC_CONST;
GType data_imports_ui_progress_pane_get_type (void) G_GNUC_CONST;
#define SPIT_DATA_IMPORTS_CONCRETE_DATA_IMPORTS_HOST_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHostPrivate))
enum  {
	SPIT_DATA_IMPORTS_CONCRETE_DATA_IMPORTS_HOST_DUMMY_PROPERTY
};
SpitDataImportsConcreteDataImportsHost* spit_data_imports_concrete_data_imports_host_new (SpitDataImportsService* service, DataImportsUIDataImportsDialog* dialog);
SpitDataImportsConcreteDataImportsHost* spit_data_imports_concrete_data_imports_host_construct (GType object_type, SpitDataImportsService* service, DataImportsUIDataImportsDialog* dialog);
PluginsStandardHostInterface* plugins_standard_host_interface_new (SpitPluggable* pluggable, const gchar* config_domain);
PluginsStandardHostInterface* plugins_standard_host_interface_construct (GType object_type, SpitPluggable* pluggable, const gchar* config_domain);
static SpitDataImportsDataImporter* spit_data_imports_concrete_data_imports_host_real_get_data_importer (SpitDataImportsPluginHost* base);
static void spit_data_imports_concrete_data_imports_host_real_start_importing (SpitDataImportsPluginHost* base);
static void spit_data_imports_concrete_data_imports_host_real_stop_importing (SpitDataImportsPluginHost* base);
static void spit_data_imports_concrete_data_imports_host_clean_up (SpitDataImportsConcreteDataImportsHost* self);
void spit_data_imports_concrete_data_imports_host_set_button_mode (SpitDataImportsConcreteDataImportsHost* self, SpitDataImportsPluginHostButtonMode mode);
void data_imports_ui_data_imports_dialog_set_close_button_mode (DataImportsUIDataImportsDialog* self);
void data_imports_ui_data_imports_dialog_set_cancel_button_mode (DataImportsUIDataImportsDialog* self);
static void spit_data_imports_concrete_data_imports_host_real_post_error (SpitDataImportsPluginHost* base, GError* err);
static void spit_data_imports_concrete_data_imports_host_real_post_error_message (SpitDataImportsPluginHost* base, const gchar* message);
void data_imports_ui_data_imports_dialog_install_pane (DataImportsUIDataImportsDialog* self, SpitDataImportsDialogPane* pane);
DataImportsUIStaticMessagePane* data_imports_ui_static_message_pane_new_with_pango (const gchar* msg);
DataImportsUIStaticMessagePane* data_imports_ui_static_message_pane_construct_with_pango (GType object_type, const gchar* msg);
GType data_imports_ui_static_message_pane_get_type (void) G_GNUC_CONST;
void data_imports_ui_data_imports_dialog_unlock_service (DataImportsUIDataImportsDialog* self);
static void spit_data_imports_concrete_data_imports_host_real_install_dialog_pane (SpitDataImportsPluginHost* base, SpitDataImportsDialogPane* pane, SpitDataImportsPluginHostButtonMode button_mode);
static void spit_data_imports_concrete_data_imports_host_real_install_static_message_pane (SpitDataImportsPluginHost* base, const gchar* message, SpitDataImportsPluginHostButtonMode button_mode);
static void spit_data_imports_concrete_data_imports_host_real_install_library_selection_pane (SpitDataImportsPluginHost* base, const gchar* welcome_message, SpitDataImportsImportableLibrary** discovered_libraries, int discovered_libraries_length1, const gchar* file_select_label);
DataImportsUILibrarySelectionPane* data_imports_ui_library_selection_pane_new (SpitDataImportsPluginHost* host, const gchar* welcome_message, SpitDataImportsImportableLibrary** discovered_libraries, int discovered_libraries_length1, const gchar* file_select_label);
DataImportsUILibrarySelectionPane* data_imports_ui_library_selection_pane_construct (GType object_type, SpitDataImportsPluginHost* host, const gchar* welcome_message, SpitDataImportsImportableLibrary** discovered_libraries, int discovered_libraries_length1, const gchar* file_select_label);
GType data_imports_ui_library_selection_pane_get_type (void) G_GNUC_CONST;
static void spit_data_imports_concrete_data_imports_host_real_install_import_progress_pane (SpitDataImportsPluginHost* base, const gchar* message);
DataImportsUIProgressPane* data_imports_ui_progress_pane_new (const gchar* message);
DataImportsUIProgressPane* data_imports_ui_progress_pane_construct (GType object_type, const gchar* message);
static void spit_data_imports_concrete_data_imports_host_real_update_import_progress_pane (SpitDataImportsPluginHost* base, gdouble progress, const gchar* progress_message);
void data_imports_ui_progress_pane_update_progress (DataImportsUIProgressPane* self, gdouble progress, const gchar* progress_message);
static void spit_data_imports_concrete_data_imports_host_real_prepare_media_items_for_import (SpitDataImportsPluginHost* base, SpitDataImportsImportableMediaItem** items, int items_length1, gdouble progress, gdouble host_progress_delta, const gchar* progress_message);
static void spit_data_imports_concrete_data_imports_host_real_finalize_import (SpitDataImportsPluginHost* base, SpitDataImportsImportedItemsCountCallback report_imported_items_count, void* report_imported_items_count_target, const gchar* finalize_message);
void library_window_switch_to_import_queue_page (LibraryWindow* self);
static void spit_data_imports_concrete_data_imports_host_finalize (GObject* obj);
GType spit_data_imports_welcome_data_imports_host_get_type (void) G_GNUC_CONST;
GType spit_data_imports_welcome_import_meta_host_get_type (void) G_GNUC_CONST;
#define SPIT_DATA_IMPORTS_WELCOME_DATA_IMPORTS_HOST_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST, SpitDataImportsWelcomeDataImportsHostPrivate))
enum  {
	SPIT_DATA_IMPORTS_WELCOME_DATA_IMPORTS_HOST_DUMMY_PROPERTY
};
SpitDataImportsWelcomeDataImportsHost* spit_data_imports_welcome_data_imports_host_new (SpitDataImportsService* service, SpitDataImportsWelcomeImportMetaHost* meta_host);
SpitDataImportsWelcomeDataImportsHost* spit_data_imports_welcome_data_imports_host_construct (GType object_type, SpitDataImportsService* service, SpitDataImportsWelcomeImportMetaHost* meta_host);
static SpitDataImportsDataImporter* spit_data_imports_welcome_data_imports_host_real_get_data_importer (SpitDataImportsPluginHost* base);
static void spit_data_imports_welcome_data_imports_host_real_start_importing (SpitDataImportsPluginHost* base);
static void spit_data_imports_welcome_data_imports_host_real_stop_importing (SpitDataImportsPluginHost* base);
static void spit_data_imports_welcome_data_imports_host_clean_up (SpitDataImportsWelcomeDataImportsHost* self);
static void spit_data_imports_welcome_data_imports_host_real_post_error (SpitDataImportsPluginHost* base, GError* err);
static void spit_data_imports_welcome_data_imports_host_real_post_error_message (SpitDataImportsPluginHost* base, const gchar* message);
static void spit_data_imports_welcome_data_imports_host_real_install_dialog_pane (SpitDataImportsPluginHost* base, SpitDataImportsDialogPane* pane, SpitDataImportsPluginHostButtonMode button_mode);
static void spit_data_imports_welcome_data_imports_host_real_install_static_message_pane (SpitDataImportsPluginHost* base, const gchar* message, SpitDataImportsPluginHostButtonMode button_mode);
static void spit_data_imports_welcome_data_imports_host_real_install_library_selection_pane (SpitDataImportsPluginHost* base, const gchar* welcome_message, SpitDataImportsImportableLibrary** discovered_libraries, int discovered_libraries_length1, const gchar* file_select_label);
GType welcome_service_entry_get_type (void) G_GNUC_CONST;
void spit_data_imports_welcome_import_meta_host_install_service_entry (SpitDataImportsWelcomeImportMetaHost* self, WelcomeServiceEntry* entry);
SpitDataImportsWelcomeImportServiceEntry* spit_data_imports_welcome_import_service_entry_new (SpitDataImportsPluginHost* host, const gchar* pluggable_name, SpitDataImportsImportableLibrary** discovered_libraries, int discovered_libraries_length1);
SpitDataImportsWelcomeImportServiceEntry* spit_data_imports_welcome_import_service_entry_construct (GType object_type, SpitDataImportsPluginHost* host, const gchar* pluggable_name, SpitDataImportsImportableLibrary** discovered_libraries, int discovered_libraries_length1);
GType spit_data_imports_welcome_import_service_entry_get_type (void) G_GNUC_CONST;
static void spit_data_imports_welcome_data_imports_host_real_install_import_progress_pane (SpitDataImportsPluginHost* base, const gchar* message);
static void spit_data_imports_welcome_data_imports_host_real_update_import_progress_pane (SpitDataImportsPluginHost* base, gdouble progress, const gchar* progress_message);
static void spit_data_imports_welcome_data_imports_host_real_prepare_media_items_for_import (SpitDataImportsPluginHost* base, SpitDataImportsImportableMediaItem** items, int items_length1, gdouble progress, gdouble host_progress_delta, const gchar* progress_message);
static void spit_data_imports_welcome_data_imports_host_real_finalize_import (SpitDataImportsPluginHost* base, SpitDataImportsImportedItemsCountCallback report_imported_items_count, void* report_imported_items_count_target, const gchar* finalize_message);
void spit_data_imports_welcome_import_meta_host_finalize_import (SpitDataImportsWelcomeImportMetaHost* self, SpitDataImportsWelcomeDataImportsHost* host);
static void spit_data_imports_welcome_data_imports_host_finalize (GObject* obj);
#define SPIT_DATA_IMPORTS_WELCOME_IMPORT_SERVICE_ENTRY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_SERVICE_ENTRY, SpitDataImportsWelcomeImportServiceEntryPrivate))
enum  {
	SPIT_DATA_IMPORTS_WELCOME_IMPORT_SERVICE_ENTRY_DUMMY_PROPERTY
};
static SpitDataImportsImportableLibrary** _vala_array_dup25 (SpitDataImportsImportableLibrary** self, int length);
static gchar* spit_data_imports_welcome_import_service_entry_real_get_service_name (WelcomeServiceEntry* base);
static void spit_data_imports_welcome_import_service_entry_real_execute (WelcomeServiceEntry* base);
static void spit_data_imports_welcome_import_service_entry_finalize (GObject* obj);
GType welcome_dialog_get_type (void) G_GNUC_CONST;
#define SPIT_DATA_IMPORTS_WELCOME_IMPORT_META_HOST_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_META_HOST, SpitDataImportsWelcomeImportMetaHostPrivate))
enum  {
	SPIT_DATA_IMPORTS_WELCOME_IMPORT_META_HOST_DUMMY_PROPERTY
};
SpitDataImportsWelcomeImportMetaHost* spit_data_imports_welcome_import_meta_host_new (WelcomeDialog* dialog);
SpitDataImportsWelcomeImportMetaHost* spit_data_imports_welcome_import_meta_host_construct (GType object_type, WelcomeDialog* dialog);
void spit_data_imports_welcome_import_meta_host_start (SpitDataImportsWelcomeImportMetaHost* self);
SpitDataImportsService** spit_data_imports_load_all_services (int* result_length1);
gchar* welcome_service_entry_get_service_name (WelcomeServiceEntry* self);
void welcome_dialog_install_service_entry (WelcomeDialog* self, WelcomeServiceEntry* entry);
static void spit_data_imports_welcome_import_meta_host_finalize (GObject* obj);
SpitDataImportsService** spit_data_imports_load_services (gboolean load_all, int* result_length1);
GeeCollection* plugins_get_pluggables_for_type (GType type, GCompareDataFunc compare_func, void* compare_func_target, GDestroyNotify compare_func_target_destroy_notify, gboolean include_disabled);
gchar* plugins_get_pluggable_module_id (SpitPluggable* needle);
static void _vala_array_add151 (SpitDataImportsService*** array, int* length, int* size, SpitDataImportsService* value);
static gint __lambda21_ (void* a, void* b);
gint utf8_cs_compare (void* a, void* b);
static gint ___lambda21____compar_fn_t (void* key1, void* key2);
GType data_object_get_type (void) G_GNUC_CONST;
GType data_source_get_type (void) G_GNUC_CONST;
GType thumbnail_source_get_type (void) G_GNUC_CONST;
GType media_source_get_type (void) G_GNUC_CONST;
gpointer batch_import_result_ref (gpointer instance);
void batch_import_result_unref (gpointer instance);
GParamSpec* param_spec_batch_import_result (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_batch_import_result (GValue* value, gpointer v_object);
void value_take_batch_import_result (GValue* value, gpointer v_object);
gpointer value_get_batch_import_result (const GValue* value);
GType batch_import_result_get_type (void) G_GNUC_CONST;
ImportManifest* import_manifest_new (GeeList* prefailed, GeeList* pre_already_imported);
ImportManifest* import_manifest_construct (GType object_type, GeeList* prefailed, GeeList* pre_already_imported);
void import_manifest_add_result (ImportManifest* self, BatchImportResult* batch_result);
void data_imports_ui_data_imports_dialog_terminate_instance (void);
gpointer import_ui_question_params_ref (gpointer instance);
void import_ui_question_params_unref (gpointer instance);
GParamSpec* import_ui_param_spec_question_params (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void import_ui_value_set_question_params (GValue* value, gpointer v_object);
void import_ui_value_take_question_params (GValue* value, gpointer v_object);
gpointer import_ui_value_get_question_params (const GValue* value);
GType import_ui_question_params_get_type (void) G_GNUC_CONST;
gboolean import_ui_report_manifest (ImportManifest* manifest, gboolean show_dest_id, ImportUIQuestionParams* question);
time_t spit_data_imports_data_import_job_get_exposure_time (SpitDataImportsDataImportJob* self);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


SpitDataImportsCoreImporter* spit_data_imports_core_importer_construct (GType object_type, SpitDataImportsPluginHost* host) {
	SpitDataImportsCoreImporter* self = NULL;
	SpitDataImportsPluginHost* _tmp0_ = NULL;
#line 14 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_val_if_fail (SPIT_DATA_IMPORTS_IS_PLUGIN_HOST (host), NULL);
#line 14 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = (SpitDataImportsCoreImporter*) g_type_create_instance (object_type);
#line 15 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = host;
#line 15 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->host = _tmp0_;
#line 14 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return self;
#line 672 "DataImportsPluginHost.c"
}


SpitDataImportsCoreImporter* spit_data_imports_core_importer_new (SpitDataImportsPluginHost* host) {
#line 14 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return spit_data_imports_core_importer_construct (SPIT_DATA_IMPORTS_TYPE_CORE_IMPORTER, host);
#line 679 "DataImportsPluginHost.c"
}


static gint64 _spit_data_imports_import_job_comparator_comparator (void* a, void* b, gpointer self) {
	gint64 result;
	result = spit_data_imports_import_job_comparator (a, b);
#line 26 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return result;
#line 688 "DataImportsPluginHost.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 35 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return self ? g_object_ref (self) : NULL;
#line 695 "DataImportsPluginHost.c"
}


static void _spit_data_imports_data_import_reporter_batch_import_import_reporter (ImportManifest* manifest, BatchImportRoll* import_roll, gpointer self) {
#line 66 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_data_import_reporter (manifest, import_roll);
#line 702 "DataImportsPluginHost.c"
}


void spit_data_imports_core_importer_prepare_media_items_for_import (SpitDataImportsCoreImporter* self, SpitDataImportsImportableMediaItem** items, int items_length1, gdouble progress, gdouble host_progress_delta, const gchar* progress_message) {
	SpitDataImportsPluginHost* _tmp0_ = NULL;
	gdouble _tmp1_ = 0.0;
	const gchar* _tmp2_ = NULL;
	SortedList* jobs = NULL;
	SortedList* _tmp3_ = NULL;
	GeeArrayList* already_imported = NULL;
	GeeArrayList* _tmp4_ = NULL;
	GeeArrayList* failed = NULL;
	GeeArrayList* _tmp5_ = NULL;
	gint item_idx = 0;
	gdouble item_progress_delta = 0.0;
	gdouble _tmp6_ = 0.0;
	SpitDataImportsImportableMediaItem** _tmp7_ = NULL;
	gint _tmp7__length1 = 0;
	SpitDataImportsImportableMediaItem** _tmp8_ = NULL;
	gint _tmp8__length1 = 0;
	SortedList* _tmp39_ = NULL;
	gint _tmp40_ = 0;
	gint _tmp41_ = 0;
	SpitDataImportsPluginHost* _tmp66_ = NULL;
	gdouble _tmp67_ = 0.0;
	gdouble _tmp68_ = 0.0;
#line 18 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (SPIT_DATA_IMPORTS_IS_CORE_IMPORTER (self));
#line 24 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = self->priv->host;
#line 24 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = progress;
#line 24 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = progress_message;
#line 24 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_plugin_host_update_import_progress_pane (_tmp0_, _tmp1_, _tmp2_);
#line 26 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp3_ = sorted_list_new (SPIT_DATA_IMPORTS_TYPE_DATA_IMPORT_JOB, (GBoxedCopyFunc) batch_import_job_ref, batch_import_job_unref, _spit_data_imports_import_job_comparator_comparator, NULL);
#line 26 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	jobs = _tmp3_;
#line 28 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp4_ = gee_array_list_new (SPIT_DATA_IMPORTS_TYPE_DATA_IMPORT_JOB, (GBoxedCopyFunc) batch_import_job_ref, batch_import_job_unref, NULL, NULL, NULL);
#line 28 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	already_imported = _tmp4_;
#line 30 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp5_ = gee_array_list_new (SPIT_DATA_IMPORTS_TYPE_DATA_IMPORT_JOB, (GBoxedCopyFunc) batch_import_job_ref, batch_import_job_unref, NULL, NULL, NULL);
#line 30 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	failed = _tmp5_;
#line 33 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	item_idx = 0;
#line 34 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp6_ = host_progress_delta;
#line 34 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp7_ = items;
#line 34 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp7__length1 = items_length1;
#line 34 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	item_progress_delta = _tmp6_ / _tmp7__length1;
#line 35 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp8_ = items;
#line 35 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp8__length1 = items_length1;
#line 765 "DataImportsPluginHost.c"
	{
		SpitDataImportsImportableMediaItem** src_item_collection = NULL;
		gint src_item_collection_length1 = 0;
		gint _src_item_collection_size_ = 0;
		gint src_item_it = 0;
#line 35 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		src_item_collection = _tmp8_;
#line 35 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		src_item_collection_length1 = _tmp8__length1;
#line 35 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		for (src_item_it = 0; src_item_it < _tmp8__length1; src_item_it = src_item_it + 1) {
#line 777 "DataImportsPluginHost.c"
			SpitDataImportsImportableMediaItem* _tmp9_ = NULL;
			SpitDataImportsImportableMediaItem* src_item = NULL;
#line 35 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp9_ = _g_object_ref0 (src_item_collection[src_item_it]);
#line 35 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			src_item = _tmp9_;
#line 784 "DataImportsPluginHost.c"
			{
				SpitDataImportsDataImportSource* import_source = NULL;
				SpitDataImportsImportableMediaItem* _tmp10_ = NULL;
				SpitDataImportsDataImportSource* _tmp11_ = NULL;
				SpitDataImportsDataImportSource* _tmp12_ = NULL;
				gboolean _tmp13_ = FALSE;
				SpitDataImportsDataImportSource* _tmp21_ = NULL;
				gboolean _tmp22_ = FALSE;
				SortedList* _tmp30_ = NULL;
				SpitDataImportsDataImportSource* _tmp31_ = NULL;
				SpitDataImportsDataImportJob* _tmp32_ = NULL;
				SpitDataImportsDataImportJob* _tmp33_ = NULL;
				gint _tmp34_ = 0;
				SpitDataImportsPluginHost* _tmp35_ = NULL;
				gdouble _tmp36_ = 0.0;
				gint _tmp37_ = 0;
				gdouble _tmp38_ = 0.0;
#line 36 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp10_ = src_item;
#line 36 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp11_ = spit_data_imports_data_import_source_new (_tmp10_);
#line 36 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				import_source = _tmp11_;
#line 38 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp12_ = import_source;
#line 38 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp13_ = spit_data_imports_data_import_source_was_backing_file_found (_tmp12_);
#line 38 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				if (!_tmp13_) {
#line 814 "DataImportsPluginHost.c"
					SpitDataImportsDataImportSource* _tmp14_ = NULL;
					gchar* _tmp15_ = NULL;
					gchar* _tmp16_ = NULL;
					GeeArrayList* _tmp17_ = NULL;
					SpitDataImportsDataImportSource* _tmp18_ = NULL;
					SpitDataImportsDataImportJob* _tmp19_ = NULL;
					SpitDataImportsDataImportJob* _tmp20_ = NULL;
#line 39 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_tmp14_ = import_source;
#line 39 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_tmp15_ = spit_data_imports_data_import_source_get_filename (_tmp14_);
#line 39 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_tmp16_ = _tmp15_;
#line 39 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					g_message ("DataImportsPluginHost.vala:39: Skipping import of %s: backing file not" \
" found", _tmp16_);
#line 39 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_g_free0 (_tmp16_);
#line 41 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_tmp17_ = failed;
#line 41 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_tmp18_ = import_source;
#line 41 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_tmp19_ = spit_data_imports_data_import_job_new (_tmp18_);
#line 41 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_tmp20_ = _tmp19_;
#line 41 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp20_);
#line 41 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_batch_import_job_unref0 (_tmp20_);
#line 43 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_spit_data_imports_data_import_source_unref0 (import_source);
#line 43 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_g_object_unref0 (src_item);
#line 43 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					continue;
#line 850 "DataImportsPluginHost.c"
				}
#line 46 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp21_ = import_source;
#line 46 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp22_ = spit_data_imports_data_import_source_is_already_imported (_tmp21_);
#line 46 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				if (_tmp22_) {
#line 858 "DataImportsPluginHost.c"
					SpitDataImportsDataImportSource* _tmp23_ = NULL;
					gchar* _tmp24_ = NULL;
					gchar* _tmp25_ = NULL;
					GeeArrayList* _tmp26_ = NULL;
					SpitDataImportsDataImportSource* _tmp27_ = NULL;
					SpitDataImportsDataImportJob* _tmp28_ = NULL;
					SpitDataImportsDataImportJob* _tmp29_ = NULL;
#line 47 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_tmp23_ = import_source;
#line 47 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_tmp24_ = spit_data_imports_data_import_source_get_filename (_tmp23_);
#line 47 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_tmp25_ = _tmp24_;
#line 47 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					g_message ("DataImportsPluginHost.vala:47: Skipping import of %s: checksum detecte" \
"d in library", _tmp25_);
#line 47 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_g_free0 (_tmp25_);
#line 49 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_tmp26_ = already_imported;
#line 49 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_tmp27_ = import_source;
#line 49 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_tmp28_ = spit_data_imports_data_import_job_new (_tmp27_);
#line 49 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_tmp29_ = _tmp28_;
#line 49 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp26_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp29_);
#line 49 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_batch_import_job_unref0 (_tmp29_);
#line 51 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_spit_data_imports_data_import_source_unref0 (import_source);
#line 51 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_g_object_unref0 (src_item);
#line 51 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					continue;
#line 894 "DataImportsPluginHost.c"
				}
#line 54 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp30_ = jobs;
#line 54 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp31_ = import_source;
#line 54 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp32_ = spit_data_imports_data_import_job_new (_tmp31_);
#line 54 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp33_ = _tmp32_;
#line 54 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				gee_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp30_, GEE_TYPE_COLLECTION, GeeCollection), _tmp33_);
#line 54 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_batch_import_job_unref0 (_tmp33_);
#line 55 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp34_ = item_idx;
#line 55 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				item_idx = _tmp34_ + 1;
#line 56 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp35_ = self->priv->host;
#line 56 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp36_ = progress;
#line 56 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp37_ = item_idx;
#line 56 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp38_ = item_progress_delta;
#line 56 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				spit_data_imports_plugin_host_update_import_progress_pane (_tmp35_, _tmp36_ + (_tmp37_ * _tmp38_), NULL);
#line 35 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_spit_data_imports_data_import_source_unref0 (import_source);
#line 35 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_g_object_unref0 (src_item);
#line 926 "DataImportsPluginHost.c"
			}
		}
	}
#line 59 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp39_ = jobs;
#line 59 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp40_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp39_, GEE_TYPE_COLLECTION, GeeCollection));
#line 59 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp41_ = _tmp40_;
#line 59 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (_tmp41_ > 0) {
#line 938 "DataImportsPluginHost.c"
		BatchImportRoll* _tmp42_ = NULL;
		gchar* db_name = NULL;
		const gchar* _tmp44_ = NULL;
		SpitDataImportsPluginHost* _tmp45_ = NULL;
		SpitDataImportsDataImporter* _tmp46_ = NULL;
		SpitDataImportsDataImporter* _tmp47_ = NULL;
		SpitDataImportsService* _tmp48_ = NULL;
		SpitDataImportsService* _tmp49_ = NULL;
		const gchar* _tmp50_ = NULL;
		gchar* _tmp51_ = NULL;
		gchar* _tmp52_ = NULL;
		BatchImport* batch_import = NULL;
		SortedList* _tmp53_ = NULL;
		const gchar* _tmp54_ = NULL;
		GeeArrayList* _tmp55_ = NULL;
		GeeArrayList* _tmp56_ = NULL;
		BatchImportRoll* _tmp57_ = NULL;
		BatchImport* _tmp58_ = NULL;
		LibraryWindow* _tmp59_ = NULL;
		LibraryWindow* _tmp60_ = NULL;
		BatchImport* _tmp61_ = NULL;
		gint _tmp62_ = 0;
		SortedList* _tmp63_ = NULL;
		gint _tmp64_ = 0;
		gint _tmp65_ = 0;
#line 63 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp42_ = self->current_import_roll;
#line 63 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		if (_tmp42_ == NULL) {
#line 968 "DataImportsPluginHost.c"
			BatchImportRoll* _tmp43_ = NULL;
#line 64 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp43_ = batch_import_roll_new ();
#line 64 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_batch_import_roll_unref0 (self->current_import_roll);
#line 64 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			self->current_import_roll = _tmp43_;
#line 976 "DataImportsPluginHost.c"
		}
#line 65 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp44_ = _ ("%s Database");
#line 65 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp45_ = self->priv->host;
#line 65 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp46_ = spit_data_imports_plugin_host_get_data_importer (_tmp45_);
#line 65 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp47_ = _tmp46_;
#line 65 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp48_ = spit_data_imports_data_importer_get_service (_tmp47_);
#line 65 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp49_ = _tmp48_;
#line 65 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp50_ = spit_pluggable_get_pluggable_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp49_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 65 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp51_ = g_strdup_printf (_tmp44_, _tmp50_);
#line 65 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp52_ = _tmp51_;
#line 65 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_g_object_unref0 (_tmp49_);
#line 65 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_g_object_unref0 (_tmp47_);
#line 65 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		db_name = _tmp52_;
#line 66 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp53_ = jobs;
#line 66 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp54_ = db_name;
#line 66 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp55_ = failed;
#line 66 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp56_ = already_imported;
#line 66 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp57_ = self->current_import_roll;
#line 66 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp58_ = batch_import_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp53_, GEE_TYPE_ITERABLE, GeeIterable), _tmp54_, _spit_data_imports_data_import_reporter_batch_import_import_reporter, NULL, _tmp55_, _tmp56_, NULL, _tmp57_, NULL);
#line 66 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		batch_import = _tmp58_;
#line 69 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp59_ = library_window_get_app ();
#line 69 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp60_ = _tmp59_;
#line 69 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp61_ = batch_import;
#line 69 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		library_window_enqueue_batch_import (_tmp60_, _tmp61_, TRUE);
#line 69 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_g_object_unref0 (_tmp60_);
#line 70 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp62_ = self->imported_items_count;
#line 70 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp63_ = jobs;
#line 70 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp64_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp63_, GEE_TYPE_COLLECTION, GeeCollection));
#line 70 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp65_ = _tmp64_;
#line 70 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		self->imported_items_count = _tmp62_ + _tmp65_;
#line 59 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_g_object_unref0 (batch_import);
#line 59 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_g_free0 (db_name);
#line 1040 "DataImportsPluginHost.c"
	}
#line 73 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp66_ = self->priv->host;
#line 73 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp67_ = progress;
#line 73 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp68_ = host_progress_delta;
#line 73 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_plugin_host_update_import_progress_pane (_tmp66_, _tmp67_ + _tmp68_, NULL);
#line 18 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (failed);
#line 18 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (already_imported);
#line 18 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (jobs);
#line 1056 "DataImportsPluginHost.c"
}


void spit_data_imports_core_importer_finalize_import (SpitDataImportsCoreImporter* self) {
	gchar* db_name = NULL;
	const gchar* _tmp0_ = NULL;
	SpitDataImportsPluginHost* _tmp1_ = NULL;
	SpitDataImportsDataImporter* _tmp2_ = NULL;
	SpitDataImportsDataImporter* _tmp3_ = NULL;
	SpitDataImportsService* _tmp4_ = NULL;
	SpitDataImportsService* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	BatchImport* batch_import = NULL;
	GeeArrayList* _tmp9_ = NULL;
	GeeArrayList* _tmp10_ = NULL;
	BatchImportRoll* _tmp11_ = NULL;
	BatchImport* _tmp12_ = NULL;
	BatchImport* _tmp13_ = NULL;
	LibraryWindow* _tmp14_ = NULL;
	LibraryWindow* _tmp15_ = NULL;
#line 76 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (SPIT_DATA_IMPORTS_IS_CORE_IMPORTER (self));
#line 78 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = _ ("%s Database");
#line 78 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = self->priv->host;
#line 78 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = spit_data_imports_plugin_host_get_data_importer (_tmp1_);
#line 78 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp3_ = _tmp2_;
#line 78 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp4_ = spit_data_imports_data_importer_get_service (_tmp3_);
#line 78 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp5_ = _tmp4_;
#line 78 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp6_ = spit_pluggable_get_pluggable_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 78 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp7_ = g_strdup_printf (_tmp0_, _tmp6_);
#line 78 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp8_ = _tmp7_;
#line 78 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (_tmp5_);
#line 78 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (_tmp3_);
#line 78 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	db_name = _tmp8_;
#line 79 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp9_ = gee_array_list_new (TYPE_BATCH_IMPORT_JOB, (GBoxedCopyFunc) batch_import_job_ref, batch_import_job_unref, NULL, NULL, NULL);
#line 79 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp10_ = _tmp9_;
#line 79 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp11_ = self->current_import_roll;
#line 79 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp12_ = batch_import_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, GEE_TYPE_ITERABLE, GeeIterable), db_name, _spit_data_imports_data_import_reporter_batch_import_import_reporter, NULL, NULL, NULL, NULL, _tmp11_, NULL);
#line 79 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp13_ = _tmp12_;
#line 79 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (_tmp10_);
#line 79 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	batch_import = _tmp13_;
#line 82 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp14_ = library_window_get_app ();
#line 82 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp15_ = _tmp14_;
#line 82 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	library_window_enqueue_batch_import (_tmp15_, batch_import, TRUE);
#line 82 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (_tmp15_);
#line 83 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_batch_import_roll_unref0 (self->current_import_roll);
#line 83 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->current_import_roll = NULL;
#line 76 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (batch_import);
#line 76 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_free0 (db_name);
#line 1135 "DataImportsPluginHost.c"
}


static void spit_data_imports_value_core_importer_init (GValue* value) {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	value->data[0].v_pointer = NULL;
#line 1142 "DataImportsPluginHost.c"
}


static void spit_data_imports_value_core_importer_free_value (GValue* value) {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (value->data[0].v_pointer) {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		spit_data_imports_core_importer_unref (value->data[0].v_pointer);
#line 1151 "DataImportsPluginHost.c"
	}
}


static void spit_data_imports_value_core_importer_copy_value (const GValue* src_value, GValue* dest_value) {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (src_value->data[0].v_pointer) {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		dest_value->data[0].v_pointer = spit_data_imports_core_importer_ref (src_value->data[0].v_pointer);
#line 1161 "DataImportsPluginHost.c"
	} else {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		dest_value->data[0].v_pointer = NULL;
#line 1165 "DataImportsPluginHost.c"
	}
}


static gpointer spit_data_imports_value_core_importer_peek_pointer (const GValue* value) {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return value->data[0].v_pointer;
#line 1173 "DataImportsPluginHost.c"
}


static gchar* spit_data_imports_value_core_importer_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (collect_values[0].v_pointer) {
#line 1180 "DataImportsPluginHost.c"
		SpitDataImportsCoreImporter* object;
		object = collect_values[0].v_pointer;
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		if (object->parent_instance.g_class == NULL) {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1187 "DataImportsPluginHost.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1191 "DataImportsPluginHost.c"
		}
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		value->data[0].v_pointer = spit_data_imports_core_importer_ref (object);
#line 1195 "DataImportsPluginHost.c"
	} else {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		value->data[0].v_pointer = NULL;
#line 1199 "DataImportsPluginHost.c"
	}
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return NULL;
#line 1203 "DataImportsPluginHost.c"
}


static gchar* spit_data_imports_value_core_importer_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	SpitDataImportsCoreImporter** object_p;
	object_p = collect_values[0].v_pointer;
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (!object_p) {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 1214 "DataImportsPluginHost.c"
	}
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (!value->data[0].v_pointer) {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		*object_p = NULL;
#line 1220 "DataImportsPluginHost.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		*object_p = value->data[0].v_pointer;
#line 1224 "DataImportsPluginHost.c"
	} else {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		*object_p = spit_data_imports_core_importer_ref (value->data[0].v_pointer);
#line 1228 "DataImportsPluginHost.c"
	}
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return NULL;
#line 1232 "DataImportsPluginHost.c"
}


GParamSpec* spit_data_imports_param_spec_core_importer (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	SpitDataImportsParamSpecCoreImporter* spec;
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_val_if_fail (g_type_is_a (object_type, SPIT_DATA_IMPORTS_TYPE_CORE_IMPORTER), NULL);
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return G_PARAM_SPEC (spec);
#line 1246 "DataImportsPluginHost.c"
}


gpointer spit_data_imports_value_get_core_importer (const GValue* value) {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, SPIT_DATA_IMPORTS_TYPE_CORE_IMPORTER), NULL);
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return value->data[0].v_pointer;
#line 1255 "DataImportsPluginHost.c"
}


void spit_data_imports_value_set_core_importer (GValue* value, gpointer v_object) {
	SpitDataImportsCoreImporter* old;
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, SPIT_DATA_IMPORTS_TYPE_CORE_IMPORTER));
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	old = value->data[0].v_pointer;
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (v_object) {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, SPIT_DATA_IMPORTS_TYPE_CORE_IMPORTER));
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		value->data[0].v_pointer = v_object;
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		spit_data_imports_core_importer_ref (value->data[0].v_pointer);
#line 1275 "DataImportsPluginHost.c"
	} else {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		value->data[0].v_pointer = NULL;
#line 1279 "DataImportsPluginHost.c"
	}
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (old) {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		spit_data_imports_core_importer_unref (old);
#line 1285 "DataImportsPluginHost.c"
	}
}


void spit_data_imports_value_take_core_importer (GValue* value, gpointer v_object) {
	SpitDataImportsCoreImporter* old;
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, SPIT_DATA_IMPORTS_TYPE_CORE_IMPORTER));
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	old = value->data[0].v_pointer;
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (v_object) {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, SPIT_DATA_IMPORTS_TYPE_CORE_IMPORTER));
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		value->data[0].v_pointer = v_object;
#line 1304 "DataImportsPluginHost.c"
	} else {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		value->data[0].v_pointer = NULL;
#line 1308 "DataImportsPluginHost.c"
	}
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (old) {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		spit_data_imports_core_importer_unref (old);
#line 1314 "DataImportsPluginHost.c"
	}
}


static void spit_data_imports_core_importer_class_init (SpitDataImportsCoreImporterClass * klass) {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_core_importer_parent_class = g_type_class_peek_parent (klass);
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	((SpitDataImportsCoreImporterClass *) klass)->finalize = spit_data_imports_core_importer_finalize;
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_type_class_add_private (klass, sizeof (SpitDataImportsCoreImporterPrivate));
#line 1326 "DataImportsPluginHost.c"
}


static void spit_data_imports_core_importer_instance_init (SpitDataImportsCoreImporter * self) {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv = SPIT_DATA_IMPORTS_CORE_IMPORTER_GET_PRIVATE (self);
#line 11 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->imported_items_count = 0;
#line 12 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->current_import_roll = NULL;
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->ref_count = 1;
#line 1339 "DataImportsPluginHost.c"
}


static void spit_data_imports_core_importer_finalize (SpitDataImportsCoreImporter* obj) {
	SpitDataImportsCoreImporter * self;
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SPIT_DATA_IMPORTS_TYPE_CORE_IMPORTER, SpitDataImportsCoreImporter);
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_signal_handlers_destroy (self);
#line 12 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_batch_import_roll_unref0 (self->current_import_roll);
#line 1351 "DataImportsPluginHost.c"
}


GType spit_data_imports_core_importer_get_type (void) {
	static volatile gsize spit_data_imports_core_importer_type_id__volatile = 0;
	if (g_once_init_enter (&spit_data_imports_core_importer_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { spit_data_imports_value_core_importer_init, spit_data_imports_value_core_importer_free_value, spit_data_imports_value_core_importer_copy_value, spit_data_imports_value_core_importer_peek_pointer, "p", spit_data_imports_value_core_importer_collect_value, "p", spit_data_imports_value_core_importer_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (SpitDataImportsCoreImporterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) spit_data_imports_core_importer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SpitDataImportsCoreImporter), 0, (GInstanceInitFunc) spit_data_imports_core_importer_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType spit_data_imports_core_importer_type_id;
		spit_data_imports_core_importer_type_id = g_type_register_fundamental (g_type_fundamental_next (), "SpitDataImportsCoreImporter", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&spit_data_imports_core_importer_type_id__volatile, spit_data_imports_core_importer_type_id);
	}
	return spit_data_imports_core_importer_type_id__volatile;
}


gpointer spit_data_imports_core_importer_ref (gpointer instance) {
	SpitDataImportsCoreImporter* self;
	self = instance;
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_atomic_int_inc (&self->ref_count);
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return instance;
#line 1376 "DataImportsPluginHost.c"
}


void spit_data_imports_core_importer_unref (gpointer instance) {
	SpitDataImportsCoreImporter* self;
	self = instance;
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		SPIT_DATA_IMPORTS_CORE_IMPORTER_GET_CLASS (self)->finalize (self);
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 1389 "DataImportsPluginHost.c"
	}
}


SpitDataImportsConcreteDataImportsHost* spit_data_imports_concrete_data_imports_host_construct (GType object_type, SpitDataImportsService* service, DataImportsUIDataImportsDialog* dialog) {
	SpitDataImportsConcreteDataImportsHost * self = NULL;
	SpitDataImportsService* _tmp0_ = NULL;
	DataImportsUIDataImportsDialog* _tmp1_ = NULL;
	SpitDataImportsService* _tmp2_ = NULL;
	SpitDataImportsDataImporter* _tmp3_ = NULL;
	SpitDataImportsCoreImporter* _tmp4_ = NULL;
#line 96 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_val_if_fail (SPIT_DATA_IMPORTS_IS_SERVICE (service), NULL);
#line 96 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_val_if_fail (DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG (dialog), NULL);
#line 97 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = service;
#line 97 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = (SpitDataImportsConcreteDataImportsHost*) plugins_standard_host_interface_construct (object_type, G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_PLUGGABLE, SpitPluggable), "data_imports");
#line 98 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = dialog;
#line 98 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->dialog = _tmp1_;
#line 100 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = service;
#line 100 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp3_ = spit_data_imports_service_create_data_importer (_tmp2_, G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 100 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (self->priv->active_importer);
#line 100 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->active_importer = _tmp3_;
#line 101 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp4_ = spit_data_imports_core_importer_new (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 101 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_spit_data_imports_core_importer_unref0 (self->priv->core_importer);
#line 101 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->core_importer = _tmp4_;
#line 96 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return self;
#line 1429 "DataImportsPluginHost.c"
}


SpitDataImportsConcreteDataImportsHost* spit_data_imports_concrete_data_imports_host_new (SpitDataImportsService* service, DataImportsUIDataImportsDialog* dialog) {
#line 96 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return spit_data_imports_concrete_data_imports_host_construct (SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, service, dialog);
#line 1436 "DataImportsPluginHost.c"
}


static SpitDataImportsDataImporter* spit_data_imports_concrete_data_imports_host_real_get_data_importer (SpitDataImportsPluginHost* base) {
	SpitDataImportsConcreteDataImportsHost * self;
	SpitDataImportsDataImporter* result = NULL;
	SpitDataImportsDataImporter* _tmp0_ = NULL;
	SpitDataImportsDataImporter* _tmp1_ = NULL;
#line 104 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHost);
#line 105 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = self->priv->active_importer;
#line 105 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 105 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	result = _tmp1_;
#line 105 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return result;
#line 1455 "DataImportsPluginHost.c"
}


static void spit_data_imports_concrete_data_imports_host_real_start_importing (SpitDataImportsPluginHost* base) {
	SpitDataImportsConcreteDataImportsHost * self;
	SpitDataImportsDataImporter* _tmp0_ = NULL;
	SpitDataImportsDataImporter* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
	SpitDataImportsDataImporter* _tmp4_ = NULL;
	SpitDataImportsDataImporter* _tmp5_ = NULL;
#line 108 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHost);
#line 109 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = spit_data_imports_plugin_host_get_data_importer (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 109 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = _tmp0_;
#line 109 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = spit_data_imports_data_importer_is_running (_tmp1_);
#line 109 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp3_ = _tmp2_;
#line 109 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (_tmp1_);
#line 109 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (_tmp3_) {
#line 110 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		return;
#line 1483 "DataImportsPluginHost.c"
	}
#line 112 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_debug ("DataImportsPluginHost.vala:112: ConcreteDataImportsHost.start_importin" \
"g( ): invoked.");
#line 114 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp4_ = spit_data_imports_plugin_host_get_data_importer (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 114 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp5_ = _tmp4_;
#line 114 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_data_importer_start (_tmp5_);
#line 114 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (_tmp5_);
#line 1495 "DataImportsPluginHost.c"
}


static void spit_data_imports_concrete_data_imports_host_real_stop_importing (SpitDataImportsPluginHost* base) {
	SpitDataImportsConcreteDataImportsHost * self;
	SpitDataImportsDataImporter* _tmp0_ = NULL;
	SpitDataImportsDataImporter* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
#line 117 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHost);
#line 118 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_debug ("DataImportsPluginHost.vala:118: ConcreteDataImportsHost.stop_importing" \
"( ): invoked.");
#line 120 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = spit_data_imports_plugin_host_get_data_importer (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 120 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = _tmp0_;
#line 120 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = spit_data_imports_data_importer_is_running (_tmp1_);
#line 120 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp3_ = _tmp2_;
#line 120 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (_tmp1_);
#line 120 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (_tmp3_) {
#line 1521 "DataImportsPluginHost.c"
		SpitDataImportsDataImporter* _tmp4_ = NULL;
		SpitDataImportsDataImporter* _tmp5_ = NULL;
#line 121 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp4_ = spit_data_imports_plugin_host_get_data_importer (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 121 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp5_ = _tmp4_;
#line 121 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		spit_data_imports_data_importer_stop (_tmp5_);
#line 121 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_g_object_unref0 (_tmp5_);
#line 1532 "DataImportsPluginHost.c"
	}
#line 123 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_concrete_data_imports_host_clean_up (self);
#line 125 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->importing_halted = TRUE;
#line 1538 "DataImportsPluginHost.c"
}


static void spit_data_imports_concrete_data_imports_host_clean_up (SpitDataImportsConcreteDataImportsHost* self) {
#line 128 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (SPIT_DATA_IMPORTS_IS_CONCRETE_DATA_IMPORTS_HOST (self));
#line 129 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (self->priv->progress_pane);
#line 129 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->progress_pane = NULL;
#line 1549 "DataImportsPluginHost.c"
}


void spit_data_imports_concrete_data_imports_host_set_button_mode (SpitDataImportsConcreteDataImportsHost* self, SpitDataImportsPluginHostButtonMode mode) {
	SpitDataImportsPluginHostButtonMode _tmp0_ = 0;
#line 132 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (SPIT_DATA_IMPORTS_IS_CONCRETE_DATA_IMPORTS_HOST (self));
#line 133 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = mode;
#line 133 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (_tmp0_ == SPIT_DATA_IMPORTS_PLUGIN_HOST_BUTTON_MODE_CLOSE) {
#line 1561 "DataImportsPluginHost.c"
		DataImportsUIDataImportsDialog* _tmp1_ = NULL;
#line 134 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp1_ = self->priv->dialog;
#line 134 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		data_imports_ui_data_imports_dialog_set_close_button_mode (_tmp1_);
#line 1567 "DataImportsPluginHost.c"
	} else {
		SpitDataImportsPluginHostButtonMode _tmp2_ = 0;
#line 135 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp2_ = mode;
#line 135 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		if (_tmp2_ == SPIT_DATA_IMPORTS_PLUGIN_HOST_BUTTON_MODE_CANCEL) {
#line 1574 "DataImportsPluginHost.c"
			DataImportsUIDataImportsDialog* _tmp3_ = NULL;
#line 136 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp3_ = self->priv->dialog;
#line 136 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			data_imports_ui_data_imports_dialog_set_cancel_button_mode (_tmp3_);
#line 1580 "DataImportsPluginHost.c"
		} else {
#line 138 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			g_error ("DataImportsPluginHost.vala:138: unrecognized button mode enumeration v" \
"alue");
#line 1584 "DataImportsPluginHost.c"
		}
	}
}


static void spit_data_imports_concrete_data_imports_host_real_post_error (SpitDataImportsPluginHost* base, GError* err) {
	SpitDataImportsConcreteDataImportsHost * self;
	GError* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 143 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHost);
#line 144 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = err;
#line 144 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = _tmp0_->message;
#line 144 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_plugin_host_post_error_message (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost), _tmp1_);
#line 1602 "DataImportsPluginHost.c"
}


static void spit_data_imports_concrete_data_imports_host_real_post_error_message (SpitDataImportsPluginHost* base, const gchar* message) {
	SpitDataImportsConcreteDataImportsHost * self;
	gchar* msg = NULL;
	const gchar* _tmp0_ = NULL;
	SpitDataImportsDataImporter* _tmp1_ = NULL;
	SpitDataImportsService* _tmp2_ = NULL;
	SpitDataImportsService* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	const gchar* _tmp12_ = NULL;
	const gchar* _tmp13_ = NULL;
	gchar* _tmp14_ = NULL;
	DataImportsUIDataImportsDialog* _tmp15_ = NULL;
	const gchar* _tmp16_ = NULL;
	DataImportsUIStaticMessagePane* _tmp17_ = NULL;
	DataImportsUIStaticMessagePane* _tmp18_ = NULL;
	DataImportsUIDataImportsDialog* _tmp19_ = NULL;
	DataImportsUIDataImportsDialog* _tmp20_ = NULL;
	SpitDataImportsDataImporter* _tmp21_ = NULL;
	SpitDataImportsDataImporter* _tmp22_ = NULL;
#line 147 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHost);
#line 147 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (message != NULL);
#line 148 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = _ ("Importing from %s can't continue because an error occurred:");
#line 148 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = self->priv->active_importer;
#line 148 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = spit_data_imports_data_importer_get_service (_tmp1_);
#line 148 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp3_ = _tmp2_;
#line 148 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp4_ = spit_pluggable_get_pluggable_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 148 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp5_ = g_strdup_printf (_tmp0_, _tmp4_);
#line 148 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp6_ = _tmp5_;
#line 148 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (_tmp3_);
#line 148 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	msg = _tmp6_;
#line 150 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp7_ = msg;
#line 150 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp8_ = message;
#line 150 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp9_ = g_markup_printf_escaped ("\n\n<i>%s</i>\n\n", _tmp8_);
#line 150 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp10_ = _tmp9_;
#line 150 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp11_ = g_strconcat (_tmp7_, _tmp10_, NULL);
#line 150 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_free0 (msg);
#line 150 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	msg = _tmp11_;
#line 150 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_free0 (_tmp10_);
#line 151 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp12_ = msg;
#line 151 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp13_ = _ ("To try importing from another service, select one from the above menu.");
#line 151 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp14_ = g_strconcat (_tmp12_, _tmp13_, NULL);
#line 151 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_free0 (msg);
#line 151 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	msg = _tmp14_;
#line 153 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp15_ = self->priv->dialog;
#line 153 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp16_ = msg;
#line 153 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp17_ = data_imports_ui_static_message_pane_new_with_pango (_tmp16_);
#line 153 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp18_ = _tmp17_;
#line 153 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	data_imports_ui_data_imports_dialog_install_pane (_tmp15_, G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, SPIT_DATA_IMPORTS_TYPE_DIALOG_PANE, SpitDataImportsDialogPane));
#line 153 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (_tmp18_);
#line 154 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp19_ = self->priv->dialog;
#line 154 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	data_imports_ui_data_imports_dialog_set_close_button_mode (_tmp19_);
#line 155 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp20_ = self->priv->dialog;
#line 155 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	data_imports_ui_data_imports_dialog_unlock_service (_tmp20_);
#line 157 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp21_ = spit_data_imports_plugin_host_get_data_importer (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 157 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp22_ = _tmp21_;
#line 157 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_data_importer_stop (_tmp22_);
#line 157 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (_tmp22_);
#line 162 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_concrete_data_imports_host_clean_up (self);
#line 147 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_free0 (msg);
#line 1712 "DataImportsPluginHost.c"
}


static void spit_data_imports_concrete_data_imports_host_real_install_dialog_pane (SpitDataImportsPluginHost* base, SpitDataImportsDialogPane* pane, SpitDataImportsPluginHostButtonMode button_mode) {
	SpitDataImportsConcreteDataImportsHost * self;
	gboolean _tmp0_ = FALSE;
	SpitDataImportsDataImporter* _tmp1_ = NULL;
	SpitDataImportsDataImporter* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	DataImportsUIDataImportsDialog* _tmp7_ = NULL;
	SpitDataImportsDialogPane* _tmp8_ = NULL;
	SpitDataImportsPluginHostButtonMode _tmp9_ = 0;
#line 165 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHost);
#line 165 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (SPIT_DATA_IMPORTS_IS_DIALOG_PANE (pane));
#line 167 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_debug ("DataImportsPluginHost.vala:167: DataImports.PluginHost: install_dialog" \
"_pane( ): invoked.");
#line 169 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = spit_data_imports_plugin_host_get_data_importer (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 169 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = _tmp1_;
#line 169 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp3_ = _tmp2_ == NULL;
#line 169 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (_tmp2_);
#line 169 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (_tmp3_) {
#line 169 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp0_ = TRUE;
#line 1743 "DataImportsPluginHost.c"
	} else {
		SpitDataImportsDataImporter* _tmp4_ = NULL;
		SpitDataImportsDataImporter* _tmp5_ = NULL;
		gboolean _tmp6_ = FALSE;
#line 169 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp4_ = spit_data_imports_plugin_host_get_data_importer (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 169 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp5_ = _tmp4_;
#line 169 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp6_ = spit_data_imports_data_importer_is_running (_tmp5_);
#line 169 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp0_ = !_tmp6_;
#line 169 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_g_object_unref0 (_tmp5_);
#line 1758 "DataImportsPluginHost.c"
	}
#line 169 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (_tmp0_) {
#line 170 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		return;
#line 1764 "DataImportsPluginHost.c"
	}
#line 172 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp7_ = self->priv->dialog;
#line 172 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp8_ = pane;
#line 172 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	data_imports_ui_data_imports_dialog_install_pane (_tmp7_, _tmp8_);
#line 174 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp9_ = button_mode;
#line 174 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_concrete_data_imports_host_set_button_mode (self, _tmp9_);
#line 1776 "DataImportsPluginHost.c"
}


static void spit_data_imports_concrete_data_imports_host_real_install_static_message_pane (SpitDataImportsPluginHost* base, const gchar* message, SpitDataImportsPluginHostButtonMode button_mode) {
	SpitDataImportsConcreteDataImportsHost * self;
	SpitDataImportsPluginHostButtonMode _tmp0_ = 0;
	DataImportsUIDataImportsDialog* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	DataImportsUIStaticMessagePane* _tmp3_ = NULL;
	DataImportsUIStaticMessagePane* _tmp4_ = NULL;
#line 177 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHost);
#line 177 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (message != NULL);
#line 180 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = button_mode;
#line 180 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_concrete_data_imports_host_set_button_mode (self, _tmp0_);
#line 182 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = self->priv->dialog;
#line 182 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = message;
#line 182 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp3_ = data_imports_ui_static_message_pane_new_with_pango (_tmp2_);
#line 182 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp4_ = _tmp3_;
#line 182 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	data_imports_ui_data_imports_dialog_install_pane (_tmp1_, G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, SPIT_DATA_IMPORTS_TYPE_DIALOG_PANE, SpitDataImportsDialogPane));
#line 182 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (_tmp4_);
#line 1807 "DataImportsPluginHost.c"
}


static void spit_data_imports_concrete_data_imports_host_real_install_library_selection_pane (SpitDataImportsPluginHost* base, const gchar* welcome_message, SpitDataImportsImportableLibrary** discovered_libraries, int discovered_libraries_length1, const gchar* file_select_label) {
	SpitDataImportsConcreteDataImportsHost * self;
	gboolean _tmp0_ = FALSE;
	SpitDataImportsImportableLibrary** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
#line 185 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHost);
#line 185 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (welcome_message != NULL);
#line 190 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = discovered_libraries;
#line 190 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1__length1 = discovered_libraries_length1;
#line 190 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (_tmp1__length1 == 0) {
#line 1826 "DataImportsPluginHost.c"
		const gchar* _tmp2_ = NULL;
#line 190 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp2_ = file_select_label;
#line 190 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp0_ = _tmp2_ == NULL;
#line 1832 "DataImportsPluginHost.c"
	} else {
#line 190 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp0_ = FALSE;
#line 1836 "DataImportsPluginHost.c"
	}
#line 190 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (_tmp0_) {
#line 191 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		spit_data_imports_plugin_host_post_error_message (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost), "Libraries or file option needed");
#line 1842 "DataImportsPluginHost.c"
	} else {
		DataImportsUIDataImportsDialog* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
		SpitDataImportsImportableLibrary** _tmp5_ = NULL;
		gint _tmp5__length1 = 0;
		const gchar* _tmp6_ = NULL;
		DataImportsUILibrarySelectionPane* _tmp7_ = NULL;
		DataImportsUILibrarySelectionPane* _tmp8_ = NULL;
#line 193 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp3_ = self->priv->dialog;
#line 193 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp4_ = welcome_message;
#line 193 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp5_ = discovered_libraries;
#line 193 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp5__length1 = discovered_libraries_length1;
#line 193 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp6_ = file_select_label;
#line 193 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp7_ = data_imports_ui_library_selection_pane_new (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost), _tmp4_, _tmp5_, _tmp5__length1, _tmp6_);
#line 193 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp8_ = _tmp7_;
#line 193 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		data_imports_ui_data_imports_dialog_install_pane (_tmp3_, G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, SPIT_DATA_IMPORTS_TYPE_DIALOG_PANE, SpitDataImportsDialogPane));
#line 193 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_g_object_unref0 (_tmp8_);
#line 1869 "DataImportsPluginHost.c"
	}
#line 199 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_concrete_data_imports_host_set_button_mode (self, SPIT_DATA_IMPORTS_PLUGIN_HOST_BUTTON_MODE_CLOSE);
#line 1873 "DataImportsPluginHost.c"
}


static void spit_data_imports_concrete_data_imports_host_real_install_import_progress_pane (SpitDataImportsPluginHost* base, const gchar* message) {
	SpitDataImportsConcreteDataImportsHost * self;
	const gchar* _tmp0_ = NULL;
	DataImportsUIProgressPane* _tmp1_ = NULL;
	DataImportsUIDataImportsDialog* _tmp2_ = NULL;
	DataImportsUIProgressPane* _tmp3_ = NULL;
	SpitDataImportsCoreImporter* _tmp4_ = NULL;
	SpitDataImportsCoreImporter* _tmp5_ = NULL;
#line 202 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHost);
#line 202 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (message != NULL);
#line 205 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = message;
#line 205 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = data_imports_ui_progress_pane_new (_tmp0_);
#line 205 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (self->priv->progress_pane);
#line 205 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->progress_pane = _tmp1_;
#line 206 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = self->priv->dialog;
#line 206 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp3_ = self->priv->progress_pane;
#line 206 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	data_imports_ui_data_imports_dialog_install_pane (_tmp2_, G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, SPIT_DATA_IMPORTS_TYPE_DIALOG_PANE, SpitDataImportsDialogPane));
#line 207 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_concrete_data_imports_host_set_button_mode (self, SPIT_DATA_IMPORTS_PLUGIN_HOST_BUTTON_MODE_CANCEL);
#line 209 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp4_ = self->priv->core_importer;
#line 209 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp4_->imported_items_count = 0;
#line 210 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp5_ = self->priv->core_importer;
#line 210 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_batch_import_roll_unref0 (_tmp5_->current_import_roll);
#line 210 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp5_->current_import_roll = NULL;
#line 1915 "DataImportsPluginHost.c"
}


static void spit_data_imports_concrete_data_imports_host_real_update_import_progress_pane (SpitDataImportsPluginHost* base, gdouble progress, const gchar* progress_message) {
	SpitDataImportsConcreteDataImportsHost * self;
	DataImportsUIProgressPane* _tmp0_ = NULL;
#line 213 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHost);
#line 217 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = self->priv->progress_pane;
#line 217 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (_tmp0_ != NULL) {
#line 1928 "DataImportsPluginHost.c"
		DataImportsUIProgressPane* _tmp1_ = NULL;
		gdouble _tmp2_ = 0.0;
		const gchar* _tmp3_ = NULL;
#line 218 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp1_ = self->priv->progress_pane;
#line 218 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp2_ = progress;
#line 218 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp3_ = progress_message;
#line 218 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		data_imports_ui_progress_pane_update_progress (_tmp1_, _tmp2_, _tmp3_);
#line 1940 "DataImportsPluginHost.c"
	}
}


static void spit_data_imports_concrete_data_imports_host_real_prepare_media_items_for_import (SpitDataImportsPluginHost* base, SpitDataImportsImportableMediaItem** items, int items_length1, gdouble progress, gdouble host_progress_delta, const gchar* progress_message) {
	SpitDataImportsConcreteDataImportsHost * self;
	SpitDataImportsCoreImporter* _tmp0_ = NULL;
	SpitDataImportsImportableMediaItem** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	gdouble _tmp2_ = 0.0;
	gdouble _tmp3_ = 0.0;
	const gchar* _tmp4_ = NULL;
#line 222 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHost);
#line 228 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = self->priv->core_importer;
#line 228 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = items;
#line 228 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1__length1 = items_length1;
#line 228 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = progress;
#line 228 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp3_ = host_progress_delta;
#line 228 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp4_ = progress_message;
#line 228 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_core_importer_prepare_media_items_for_import (_tmp0_, _tmp1_, _tmp1__length1, _tmp2_, _tmp3_, _tmp4_);
#line 1969 "DataImportsPluginHost.c"
}


static void spit_data_imports_concrete_data_imports_host_real_finalize_import (SpitDataImportsPluginHost* base, SpitDataImportsImportedItemsCountCallback report_imported_items_count, void* report_imported_items_count_target, const gchar* finalize_message) {
	SpitDataImportsConcreteDataImportsHost * self;
	const gchar* _tmp0_ = NULL;
	SpitDataImportsCoreImporter* _tmp1_ = NULL;
	SpitDataImportsImportedItemsCountCallback _tmp2_ = NULL;
	void* _tmp2__target = NULL;
	SpitDataImportsCoreImporter* _tmp3_ = NULL;
	gint _tmp4_ = 0;
	SpitDataImportsCoreImporter* _tmp5_ = NULL;
	gint _tmp6_ = 0;
#line 231 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHost);
#line 235 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = finalize_message;
#line 235 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_plugin_host_update_import_progress_pane (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost), 1.0, _tmp0_);
#line 236 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_concrete_data_imports_host_set_button_mode (self, SPIT_DATA_IMPORTS_PLUGIN_HOST_BUTTON_MODE_CLOSE);
#line 237 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = self->priv->core_importer;
#line 237 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_core_importer_finalize_import (_tmp1_);
#line 238 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = report_imported_items_count;
#line 238 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2__target = report_imported_items_count_target;
#line 238 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp3_ = self->priv->core_importer;
#line 238 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp4_ = _tmp3_->imported_items_count;
#line 238 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ (_tmp4_, _tmp2__target);
#line 239 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp5_ = self->priv->core_importer;
#line 239 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp6_ = _tmp5_->imported_items_count;
#line 239 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (_tmp6_ > 0) {
#line 2011 "DataImportsPluginHost.c"
		LibraryWindow* _tmp7_ = NULL;
		LibraryWindow* _tmp8_ = NULL;
#line 240 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp7_ = library_window_get_app ();
#line 240 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp8_ = _tmp7_;
#line 240 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		library_window_switch_to_import_queue_page (_tmp8_);
#line 240 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_g_object_unref0 (_tmp8_);
#line 2022 "DataImportsPluginHost.c"
	}
}


static void spit_data_imports_concrete_data_imports_host_class_init (SpitDataImportsConcreteDataImportsHostClass * klass) {
#line 87 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_concrete_data_imports_host_parent_class = g_type_class_peek_parent (klass);
#line 87 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_type_class_add_private (klass, sizeof (SpitDataImportsConcreteDataImportsHostPrivate));
#line 87 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	G_OBJECT_CLASS (klass)->finalize = spit_data_imports_concrete_data_imports_host_finalize;
#line 2034 "DataImportsPluginHost.c"
}


static void spit_data_imports_concrete_data_imports_host_spit_data_imports_plugin_host_interface_init (SpitDataImportsPluginHostIface * iface) {
#line 87 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_concrete_data_imports_host_spit_data_imports_plugin_host_parent_iface = g_type_interface_peek_parent (iface);
#line 87 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->get_data_importer = (SpitDataImportsDataImporter* (*)(SpitDataImportsPluginHost*)) spit_data_imports_concrete_data_imports_host_real_get_data_importer;
#line 87 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->start_importing = (void (*)(SpitDataImportsPluginHost*)) spit_data_imports_concrete_data_imports_host_real_start_importing;
#line 87 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->stop_importing = (void (*)(SpitDataImportsPluginHost*)) spit_data_imports_concrete_data_imports_host_real_stop_importing;
#line 87 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->post_error = (void (*)(SpitDataImportsPluginHost*, GError*)) spit_data_imports_concrete_data_imports_host_real_post_error;
#line 87 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->post_error_message = (void (*)(SpitDataImportsPluginHost*, const gchar*)) spit_data_imports_concrete_data_imports_host_real_post_error_message;
#line 87 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->install_dialog_pane = (void (*)(SpitDataImportsPluginHost*, SpitDataImportsDialogPane*, SpitDataImportsPluginHostButtonMode)) spit_data_imports_concrete_data_imports_host_real_install_dialog_pane;
#line 87 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->install_static_message_pane = (void (*)(SpitDataImportsPluginHost*, const gchar*, SpitDataImportsPluginHostButtonMode)) spit_data_imports_concrete_data_imports_host_real_install_static_message_pane;
#line 87 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->install_library_selection_pane = (void (*)(SpitDataImportsPluginHost*, const gchar*, SpitDataImportsImportableLibrary**, int, const gchar*)) spit_data_imports_concrete_data_imports_host_real_install_library_selection_pane;
#line 87 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->install_import_progress_pane = (void (*)(SpitDataImportsPluginHost*, const gchar*)) spit_data_imports_concrete_data_imports_host_real_install_import_progress_pane;
#line 87 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->update_import_progress_pane = (void (*)(SpitDataImportsPluginHost*, gdouble, const gchar*)) spit_data_imports_concrete_data_imports_host_real_update_import_progress_pane;
#line 87 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->prepare_media_items_for_import = (void (*)(SpitDataImportsPluginHost*, SpitDataImportsImportableMediaItem**, int, gdouble, gdouble, const gchar*)) spit_data_imports_concrete_data_imports_host_real_prepare_media_items_for_import;
#line 87 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->finalize_import = (void (*)(SpitDataImportsPluginHost*, SpitDataImportsImportedItemsCountCallback, void*, const gchar*)) spit_data_imports_concrete_data_imports_host_real_finalize_import;
#line 2065 "DataImportsPluginHost.c"
}


static void spit_data_imports_concrete_data_imports_host_instance_init (SpitDataImportsConcreteDataImportsHost * self) {
#line 87 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv = SPIT_DATA_IMPORTS_CONCRETE_DATA_IMPORTS_HOST_GET_PRIVATE (self);
#line 90 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->active_importer = NULL;
#line 91 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->dialog = NULL;
#line 92 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->progress_pane = NULL;
#line 93 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->importing_halted = FALSE;
#line 2080 "DataImportsPluginHost.c"
}


static void spit_data_imports_concrete_data_imports_host_finalize (GObject* obj) {
	SpitDataImportsConcreteDataImportsHost * self;
#line 87 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHost);
#line 90 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (self->priv->active_importer);
#line 92 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (self->priv->progress_pane);
#line 94 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_spit_data_imports_core_importer_unref0 (self->priv->core_importer);
#line 87 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	G_OBJECT_CLASS (spit_data_imports_concrete_data_imports_host_parent_class)->finalize (obj);
#line 2096 "DataImportsPluginHost.c"
}


GType spit_data_imports_concrete_data_imports_host_get_type (void) {
	static volatile gsize spit_data_imports_concrete_data_imports_host_type_id__volatile = 0;
	if (g_once_init_enter (&spit_data_imports_concrete_data_imports_host_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SpitDataImportsConcreteDataImportsHostClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) spit_data_imports_concrete_data_imports_host_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SpitDataImportsConcreteDataImportsHost), 0, (GInstanceInitFunc) spit_data_imports_concrete_data_imports_host_instance_init, NULL };
		static const GInterfaceInfo spit_data_imports_plugin_host_info = { (GInterfaceInitFunc) spit_data_imports_concrete_data_imports_host_spit_data_imports_plugin_host_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType spit_data_imports_concrete_data_imports_host_type_id;
		spit_data_imports_concrete_data_imports_host_type_id = g_type_register_static (PLUGINS_TYPE_STANDARD_HOST_INTERFACE, "SpitDataImportsConcreteDataImportsHost", &g_define_type_info, 0);
		g_type_add_interface_static (spit_data_imports_concrete_data_imports_host_type_id, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, &spit_data_imports_plugin_host_info);
		g_once_init_leave (&spit_data_imports_concrete_data_imports_host_type_id__volatile, spit_data_imports_concrete_data_imports_host_type_id);
	}
	return spit_data_imports_concrete_data_imports_host_type_id__volatile;
}


SpitDataImportsWelcomeDataImportsHost* spit_data_imports_welcome_data_imports_host_construct (GType object_type, SpitDataImportsService* service, SpitDataImportsWelcomeImportMetaHost* meta_host) {
	SpitDataImportsWelcomeDataImportsHost * self = NULL;
	SpitDataImportsService* _tmp0_ = NULL;
	SpitDataImportsService* _tmp1_ = NULL;
	SpitDataImportsDataImporter* _tmp2_ = NULL;
	SpitDataImportsCoreImporter* _tmp3_ = NULL;
	SpitDataImportsWelcomeImportMetaHost* _tmp4_ = NULL;
#line 252 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_val_if_fail (SPIT_DATA_IMPORTS_IS_SERVICE (service), NULL);
#line 252 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_val_if_fail (SPIT_DATA_IMPORTS_IS_WELCOME_IMPORT_META_HOST (meta_host), NULL);
#line 253 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = service;
#line 253 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = (SpitDataImportsWelcomeDataImportsHost*) plugins_standard_host_interface_construct (object_type, G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_PLUGGABLE, SpitPluggable), "data_imports");
#line 255 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = service;
#line 255 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = spit_data_imports_service_create_data_importer (_tmp1_, G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 255 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (self->priv->active_importer);
#line 255 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->active_importer = _tmp2_;
#line 256 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp3_ = spit_data_imports_core_importer_new (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 256 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_spit_data_imports_core_importer_unref0 (self->priv->core_importer);
#line 256 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->core_importer = _tmp3_;
#line 257 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp4_ = meta_host;
#line 257 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->meta_host = _tmp4_;
#line 252 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return self;
#line 2149 "DataImportsPluginHost.c"
}


SpitDataImportsWelcomeDataImportsHost* spit_data_imports_welcome_data_imports_host_new (SpitDataImportsService* service, SpitDataImportsWelcomeImportMetaHost* meta_host) {
#line 252 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return spit_data_imports_welcome_data_imports_host_construct (SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST, service, meta_host);
#line 2156 "DataImportsPluginHost.c"
}


static SpitDataImportsDataImporter* spit_data_imports_welcome_data_imports_host_real_get_data_importer (SpitDataImportsPluginHost* base) {
	SpitDataImportsWelcomeDataImportsHost * self;
	SpitDataImportsDataImporter* result = NULL;
	SpitDataImportsDataImporter* _tmp0_ = NULL;
	SpitDataImportsDataImporter* _tmp1_ = NULL;
#line 260 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST, SpitDataImportsWelcomeDataImportsHost);
#line 261 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = self->priv->active_importer;
#line 261 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 261 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	result = _tmp1_;
#line 261 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return result;
#line 2175 "DataImportsPluginHost.c"
}


static void spit_data_imports_welcome_data_imports_host_real_start_importing (SpitDataImportsPluginHost* base) {
	SpitDataImportsWelcomeDataImportsHost * self;
	SpitDataImportsDataImporter* _tmp0_ = NULL;
	SpitDataImportsDataImporter* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
	SpitDataImportsDataImporter* _tmp4_ = NULL;
	SpitDataImportsDataImporter* _tmp5_ = NULL;
#line 264 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST, SpitDataImportsWelcomeDataImportsHost);
#line 265 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = spit_data_imports_plugin_host_get_data_importer (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 265 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = _tmp0_;
#line 265 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = spit_data_imports_data_importer_is_running (_tmp1_);
#line 265 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp3_ = _tmp2_;
#line 265 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (_tmp1_);
#line 265 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (_tmp3_) {
#line 266 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		return;
#line 2203 "DataImportsPluginHost.c"
	}
#line 268 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_debug ("DataImportsPluginHost.vala:268: WelcomeDataImportsHost.start_importing" \
"( ): invoked.");
#line 270 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp4_ = spit_data_imports_plugin_host_get_data_importer (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 270 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp5_ = _tmp4_;
#line 270 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_data_importer_start (_tmp5_);
#line 270 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (_tmp5_);
#line 2215 "DataImportsPluginHost.c"
}


static void spit_data_imports_welcome_data_imports_host_real_stop_importing (SpitDataImportsPluginHost* base) {
	SpitDataImportsWelcomeDataImportsHost * self;
	SpitDataImportsDataImporter* _tmp0_ = NULL;
	SpitDataImportsDataImporter* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
#line 273 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST, SpitDataImportsWelcomeDataImportsHost);
#line 274 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_debug ("DataImportsPluginHost.vala:274: WelcomeDataImportsHost.stop_importing(" \
" ): invoked.");
#line 276 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = spit_data_imports_plugin_host_get_data_importer (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 276 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = _tmp0_;
#line 276 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = spit_data_imports_data_importer_is_running (_tmp1_);
#line 276 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp3_ = _tmp2_;
#line 276 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (_tmp1_);
#line 276 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (_tmp3_) {
#line 2241 "DataImportsPluginHost.c"
		SpitDataImportsDataImporter* _tmp4_ = NULL;
		SpitDataImportsDataImporter* _tmp5_ = NULL;
#line 277 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp4_ = spit_data_imports_plugin_host_get_data_importer (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 277 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp5_ = _tmp4_;
#line 277 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		spit_data_imports_data_importer_stop (_tmp5_);
#line 277 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_g_object_unref0 (_tmp5_);
#line 2252 "DataImportsPluginHost.c"
	}
#line 279 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_welcome_data_imports_host_clean_up (self);
#line 281 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->importing_halted = TRUE;
#line 2258 "DataImportsPluginHost.c"
}


static void spit_data_imports_welcome_data_imports_host_clean_up (SpitDataImportsWelcomeDataImportsHost* self) {
#line 284 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (SPIT_DATA_IMPORTS_IS_WELCOME_DATA_IMPORTS_HOST (self));
#line 2265 "DataImportsPluginHost.c"
}


static void spit_data_imports_welcome_data_imports_host_real_post_error (SpitDataImportsPluginHost* base, GError* err) {
	SpitDataImportsWelcomeDataImportsHost * self;
	GError* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 289 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST, SpitDataImportsWelcomeDataImportsHost);
#line 290 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = err;
#line 290 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = _tmp0_->message;
#line 290 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_plugin_host_post_error_message (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost), _tmp1_);
#line 2281 "DataImportsPluginHost.c"
}


static void spit_data_imports_welcome_data_imports_host_real_post_error_message (SpitDataImportsPluginHost* base, const gchar* message) {
	SpitDataImportsWelcomeDataImportsHost * self;
	gchar* msg = NULL;
	const gchar* _tmp0_ = NULL;
	SpitDataImportsDataImporter* _tmp1_ = NULL;
	SpitDataImportsService* _tmp2_ = NULL;
	SpitDataImportsService* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	SpitDataImportsDataImporter* _tmp7_ = NULL;
	SpitDataImportsDataImporter* _tmp8_ = NULL;
#line 293 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST, SpitDataImportsWelcomeDataImportsHost);
#line 293 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (message != NULL);
#line 294 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = _ ("Importing from %s can't continue because an error occurred:");
#line 294 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = self->priv->active_importer;
#line 294 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = spit_data_imports_data_importer_get_service (_tmp1_);
#line 294 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp3_ = _tmp2_;
#line 294 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp4_ = spit_pluggable_get_pluggable_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 294 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp5_ = g_strdup_printf (_tmp0_, _tmp4_);
#line 294 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp6_ = _tmp5_;
#line 294 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (_tmp3_);
#line 294 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	msg = _tmp6_;
#line 297 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_debug ("DataImportsPluginHost.vala:297: %s", msg);
#line 299 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp7_ = spit_data_imports_plugin_host_get_data_importer (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 299 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp8_ = _tmp7_;
#line 299 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_data_importer_stop (_tmp8_);
#line 299 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (_tmp8_);
#line 304 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_welcome_data_imports_host_clean_up (self);
#line 293 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_free0 (msg);
#line 2333 "DataImportsPluginHost.c"
}


static void spit_data_imports_welcome_data_imports_host_real_install_dialog_pane (SpitDataImportsPluginHost* base, SpitDataImportsDialogPane* pane, SpitDataImportsPluginHostButtonMode button_mode) {
	SpitDataImportsWelcomeDataImportsHost * self;
#line 307 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST, SpitDataImportsWelcomeDataImportsHost);
#line 307 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (SPIT_DATA_IMPORTS_IS_DIALOG_PANE (pane));
#line 2343 "DataImportsPluginHost.c"
}


static void spit_data_imports_welcome_data_imports_host_real_install_static_message_pane (SpitDataImportsPluginHost* base, const gchar* message, SpitDataImportsPluginHostButtonMode button_mode) {
	SpitDataImportsWelcomeDataImportsHost * self;
#line 312 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST, SpitDataImportsWelcomeDataImportsHost);
#line 312 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (message != NULL);
#line 2353 "DataImportsPluginHost.c"
}


static void spit_data_imports_welcome_data_imports_host_real_install_library_selection_pane (SpitDataImportsPluginHost* base, const gchar* welcome_message, SpitDataImportsImportableLibrary** discovered_libraries, int discovered_libraries_length1, const gchar* file_select_label) {
	SpitDataImportsWelcomeDataImportsHost * self;
	SpitDataImportsDataImporter* _tmp0_ = NULL;
	SpitDataImportsDataImporter* _tmp1_ = NULL;
	SpitDataImportsService* _tmp2_ = NULL;
	SpitDataImportsService* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	SpitDataImportsImportableLibrary** _tmp7_ = NULL;
	gint _tmp7__length1 = 0;
#line 317 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST, SpitDataImportsWelcomeDataImportsHost);
#line 317 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (welcome_message != NULL);
#line 322 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = spit_data_imports_plugin_host_get_data_importer (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 322 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = _tmp0_;
#line 322 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = spit_data_imports_data_importer_get_service (_tmp1_);
#line 322 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp3_ = _tmp2_;
#line 322 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp4_ = spit_pluggable_get_pluggable_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 322 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp5_ = g_strdup_printf ("WelcomeDataImportsHost: Installing library selection pane for %s", _tmp4_);
#line 322 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp6_ = _tmp5_;
#line 322 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_debug ("DataImportsPluginHost.vala:322: %s", _tmp6_);
#line 322 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_free0 (_tmp6_);
#line 322 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (_tmp3_);
#line 322 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (_tmp1_);
#line 323 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp7_ = discovered_libraries;
#line 323 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp7__length1 = discovered_libraries_length1;
#line 323 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (_tmp7__length1 > 0) {
#line 2400 "DataImportsPluginHost.c"
		SpitDataImportsWelcomeImportMetaHost* _tmp8_ = NULL;
		SpitDataImportsDataImporter* _tmp9_ = NULL;
		SpitDataImportsDataImporter* _tmp10_ = NULL;
		SpitDataImportsService* _tmp11_ = NULL;
		SpitDataImportsService* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
		SpitDataImportsImportableLibrary** _tmp14_ = NULL;
		gint _tmp14__length1 = 0;
		SpitDataImportsWelcomeImportServiceEntry* _tmp15_ = NULL;
		SpitDataImportsWelcomeImportServiceEntry* _tmp16_ = NULL;
#line 324 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp8_ = self->priv->meta_host;
#line 324 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp9_ = spit_data_imports_plugin_host_get_data_importer (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 324 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp10_ = _tmp9_;
#line 324 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp11_ = spit_data_imports_data_importer_get_service (_tmp10_);
#line 324 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp12_ = _tmp11_;
#line 324 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp13_ = spit_pluggable_get_pluggable_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 324 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp14_ = discovered_libraries;
#line 324 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp14__length1 = discovered_libraries_length1;
#line 324 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp15_ = spit_data_imports_welcome_import_service_entry_new (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost), _tmp13_, _tmp14_, _tmp14__length1);
#line 324 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp16_ = _tmp15_;
#line 324 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		spit_data_imports_welcome_import_meta_host_install_service_entry (_tmp8_, G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, TYPE_WELCOME_SERVICE_ENTRY, WelcomeServiceEntry));
#line 324 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_g_object_unref0 (_tmp16_);
#line 324 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_g_object_unref0 (_tmp12_);
#line 324 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_g_object_unref0 (_tmp10_);
#line 2439 "DataImportsPluginHost.c"
	}
}


static void spit_data_imports_welcome_data_imports_host_real_install_import_progress_pane (SpitDataImportsPluginHost* base, const gchar* message) {
	SpitDataImportsWelcomeDataImportsHost * self;
#line 332 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST, SpitDataImportsWelcomeDataImportsHost);
#line 332 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (message != NULL);
#line 2450 "DataImportsPluginHost.c"
}


static void spit_data_imports_welcome_data_imports_host_real_update_import_progress_pane (SpitDataImportsPluginHost* base, gdouble progress, const gchar* progress_message) {
	SpitDataImportsWelcomeDataImportsHost * self;
#line 338 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST, SpitDataImportsWelcomeDataImportsHost);
#line 2458 "DataImportsPluginHost.c"
}


static void spit_data_imports_welcome_data_imports_host_real_prepare_media_items_for_import (SpitDataImportsPluginHost* base, SpitDataImportsImportableMediaItem** items, int items_length1, gdouble progress, gdouble host_progress_delta, const gchar* progress_message) {
	SpitDataImportsWelcomeDataImportsHost * self;
	SpitDataImportsCoreImporter* _tmp0_ = NULL;
	SpitDataImportsImportableMediaItem** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	gdouble _tmp2_ = 0.0;
	gdouble _tmp3_ = 0.0;
	const gchar* _tmp4_ = NULL;
#line 345 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST, SpitDataImportsWelcomeDataImportsHost);
#line 351 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = self->priv->core_importer;
#line 351 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = items;
#line 351 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1__length1 = items_length1;
#line 351 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = progress;
#line 351 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp3_ = host_progress_delta;
#line 351 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp4_ = progress_message;
#line 351 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_core_importer_prepare_media_items_for_import (_tmp0_, _tmp1_, _tmp1__length1, _tmp2_, _tmp3_, _tmp4_);
#line 2486 "DataImportsPluginHost.c"
}


static void spit_data_imports_welcome_data_imports_host_real_finalize_import (SpitDataImportsPluginHost* base, SpitDataImportsImportedItemsCountCallback report_imported_items_count, void* report_imported_items_count_target, const gchar* finalize_message) {
	SpitDataImportsWelcomeDataImportsHost * self;
	SpitDataImportsCoreImporter* _tmp0_ = NULL;
	SpitDataImportsImportedItemsCountCallback _tmp1_ = NULL;
	void* _tmp1__target = NULL;
	SpitDataImportsCoreImporter* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	SpitDataImportsWelcomeImportMetaHost* _tmp4_ = NULL;
#line 354 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST, SpitDataImportsWelcomeDataImportsHost);
#line 358 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = self->priv->core_importer;
#line 358 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_core_importer_finalize_import (_tmp0_);
#line 359 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = report_imported_items_count;
#line 359 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1__target = report_imported_items_count_target;
#line 359 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = self->priv->core_importer;
#line 359 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp3_ = _tmp2_->imported_items_count;
#line 359 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ (_tmp3_, _tmp1__target);
#line 360 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp4_ = self->priv->meta_host;
#line 360 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_welcome_import_meta_host_finalize_import (_tmp4_, self);
#line 2518 "DataImportsPluginHost.c"
}


static void spit_data_imports_welcome_data_imports_host_class_init (SpitDataImportsWelcomeDataImportsHostClass * klass) {
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_welcome_data_imports_host_parent_class = g_type_class_peek_parent (klass);
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_type_class_add_private (klass, sizeof (SpitDataImportsWelcomeDataImportsHostPrivate));
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	G_OBJECT_CLASS (klass)->finalize = spit_data_imports_welcome_data_imports_host_finalize;
#line 2529 "DataImportsPluginHost.c"
}


static void spit_data_imports_welcome_data_imports_host_spit_data_imports_plugin_host_interface_init (SpitDataImportsPluginHostIface * iface) {
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_welcome_data_imports_host_spit_data_imports_plugin_host_parent_iface = g_type_interface_peek_parent (iface);
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->get_data_importer = (SpitDataImportsDataImporter* (*)(SpitDataImportsPluginHost*)) spit_data_imports_welcome_data_imports_host_real_get_data_importer;
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->start_importing = (void (*)(SpitDataImportsPluginHost*)) spit_data_imports_welcome_data_imports_host_real_start_importing;
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->stop_importing = (void (*)(SpitDataImportsPluginHost*)) spit_data_imports_welcome_data_imports_host_real_stop_importing;
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->post_error = (void (*)(SpitDataImportsPluginHost*, GError*)) spit_data_imports_welcome_data_imports_host_real_post_error;
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->post_error_message = (void (*)(SpitDataImportsPluginHost*, const gchar*)) spit_data_imports_welcome_data_imports_host_real_post_error_message;
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->install_dialog_pane = (void (*)(SpitDataImportsPluginHost*, SpitDataImportsDialogPane*, SpitDataImportsPluginHostButtonMode)) spit_data_imports_welcome_data_imports_host_real_install_dialog_pane;
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->install_static_message_pane = (void (*)(SpitDataImportsPluginHost*, const gchar*, SpitDataImportsPluginHostButtonMode)) spit_data_imports_welcome_data_imports_host_real_install_static_message_pane;
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->install_library_selection_pane = (void (*)(SpitDataImportsPluginHost*, const gchar*, SpitDataImportsImportableLibrary**, int, const gchar*)) spit_data_imports_welcome_data_imports_host_real_install_library_selection_pane;
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->install_import_progress_pane = (void (*)(SpitDataImportsPluginHost*, const gchar*)) spit_data_imports_welcome_data_imports_host_real_install_import_progress_pane;
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->update_import_progress_pane = (void (*)(SpitDataImportsPluginHost*, gdouble, const gchar*)) spit_data_imports_welcome_data_imports_host_real_update_import_progress_pane;
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->prepare_media_items_for_import = (void (*)(SpitDataImportsPluginHost*, SpitDataImportsImportableMediaItem**, int, gdouble, gdouble, const gchar*)) spit_data_imports_welcome_data_imports_host_real_prepare_media_items_for_import;
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->finalize_import = (void (*)(SpitDataImportsPluginHost*, SpitDataImportsImportedItemsCountCallback, void*, const gchar*)) spit_data_imports_welcome_data_imports_host_real_finalize_import;
#line 2560 "DataImportsPluginHost.c"
}


static void spit_data_imports_welcome_data_imports_host_instance_init (SpitDataImportsWelcomeDataImportsHost * self) {
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv = SPIT_DATA_IMPORTS_WELCOME_DATA_IMPORTS_HOST_GET_PRIVATE (self);
#line 248 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->active_importer = NULL;
#line 249 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->importing_halted = FALSE;
#line 2571 "DataImportsPluginHost.c"
}


static void spit_data_imports_welcome_data_imports_host_finalize (GObject* obj) {
	SpitDataImportsWelcomeDataImportsHost * self;
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST, SpitDataImportsWelcomeDataImportsHost);
#line 248 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (self->priv->active_importer);
#line 250 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_spit_data_imports_core_importer_unref0 (self->priv->core_importer);
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	G_OBJECT_CLASS (spit_data_imports_welcome_data_imports_host_parent_class)->finalize (obj);
#line 2585 "DataImportsPluginHost.c"
}


GType spit_data_imports_welcome_data_imports_host_get_type (void) {
	static volatile gsize spit_data_imports_welcome_data_imports_host_type_id__volatile = 0;
	if (g_once_init_enter (&spit_data_imports_welcome_data_imports_host_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SpitDataImportsWelcomeDataImportsHostClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) spit_data_imports_welcome_data_imports_host_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SpitDataImportsWelcomeDataImportsHost), 0, (GInstanceInitFunc) spit_data_imports_welcome_data_imports_host_instance_init, NULL };
		static const GInterfaceInfo spit_data_imports_plugin_host_info = { (GInterfaceInitFunc) spit_data_imports_welcome_data_imports_host_spit_data_imports_plugin_host_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType spit_data_imports_welcome_data_imports_host_type_id;
		spit_data_imports_welcome_data_imports_host_type_id = g_type_register_static (PLUGINS_TYPE_STANDARD_HOST_INTERFACE, "SpitDataImportsWelcomeDataImportsHost", &g_define_type_info, 0);
		g_type_add_interface_static (spit_data_imports_welcome_data_imports_host_type_id, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, &spit_data_imports_plugin_host_info);
		g_once_init_leave (&spit_data_imports_welcome_data_imports_host_type_id__volatile, spit_data_imports_welcome_data_imports_host_type_id);
	}
	return spit_data_imports_welcome_data_imports_host_type_id__volatile;
}


static SpitDataImportsImportableLibrary** _vala_array_dup25 (SpitDataImportsImportableLibrary** self, int length) {
	SpitDataImportsImportableLibrary** result;
	int i;
#line 378 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	result = g_new0 (SpitDataImportsImportableLibrary*, length + 1);
#line 378 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	for (i = 0; i < length; i++) {
#line 2610 "DataImportsPluginHost.c"
		SpitDataImportsImportableLibrary* _tmp0_ = NULL;
#line 378 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp0_ = _g_object_ref0 (self[i]);
#line 378 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		result[i] = _tmp0_;
#line 2616 "DataImportsPluginHost.c"
	}
#line 378 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return result;
#line 2620 "DataImportsPluginHost.c"
}


SpitDataImportsWelcomeImportServiceEntry* spit_data_imports_welcome_import_service_entry_construct (GType object_type, SpitDataImportsPluginHost* host, const gchar* pluggable_name, SpitDataImportsImportableLibrary** discovered_libraries, int discovered_libraries_length1) {
	SpitDataImportsWelcomeImportServiceEntry * self = NULL;
	SpitDataImportsPluginHost* _tmp0_ = NULL;
	SpitDataImportsPluginHost* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	SpitDataImportsImportableLibrary** _tmp4_ = NULL;
	gint _tmp4__length1 = 0;
	SpitDataImportsImportableLibrary** _tmp5_ = NULL;
	gint _tmp5__length1 = 0;
#line 372 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_val_if_fail (SPIT_DATA_IMPORTS_IS_PLUGIN_HOST (host), NULL);
#line 372 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_val_if_fail (pluggable_name != NULL, NULL);
#line 372 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = (SpitDataImportsWelcomeImportServiceEntry*) g_object_new (object_type, NULL);
#line 376 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = host;
#line 376 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 376 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (self->priv->host);
#line 376 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->host = _tmp1_;
#line 377 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = pluggable_name;
#line 377 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 377 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_free0 (self->priv->pluggable_name);
#line 377 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->pluggable_name = _tmp3_;
#line 378 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp4_ = discovered_libraries;
#line 378 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp4__length1 = discovered_libraries_length1;
#line 378 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp5_ = (_tmp4_ != NULL) ? _vala_array_dup25 (_tmp4_, _tmp4__length1) : ((gpointer) _tmp4_);
#line 378 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp5__length1 = _tmp4__length1;
#line 378 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->discovered_libraries = (_vala_array_free (self->priv->discovered_libraries, self->priv->discovered_libraries_length1, (GDestroyNotify) g_object_unref), NULL);
#line 378 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->discovered_libraries = _tmp5_;
#line 378 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->discovered_libraries_length1 = _tmp5__length1;
#line 378 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->_discovered_libraries_size_ = self->priv->discovered_libraries_length1;
#line 372 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return self;
#line 2674 "DataImportsPluginHost.c"
}


SpitDataImportsWelcomeImportServiceEntry* spit_data_imports_welcome_import_service_entry_new (SpitDataImportsPluginHost* host, const gchar* pluggable_name, SpitDataImportsImportableLibrary** discovered_libraries, int discovered_libraries_length1) {
#line 372 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return spit_data_imports_welcome_import_service_entry_construct (SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_SERVICE_ENTRY, host, pluggable_name, discovered_libraries, discovered_libraries_length1);
#line 2681 "DataImportsPluginHost.c"
}


static gchar* spit_data_imports_welcome_import_service_entry_real_get_service_name (WelcomeServiceEntry* base) {
	SpitDataImportsWelcomeImportServiceEntry * self;
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 381 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_SERVICE_ENTRY, SpitDataImportsWelcomeImportServiceEntry);
#line 382 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = self->priv->pluggable_name;
#line 382 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 382 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	result = _tmp1_;
#line 382 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return result;
#line 2700 "DataImportsPluginHost.c"
}


static void spit_data_imports_welcome_import_service_entry_real_execute (WelcomeServiceEntry* base) {
	SpitDataImportsWelcomeImportServiceEntry * self;
	SpitDataImportsImportableLibrary** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
#line 385 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_SERVICE_ENTRY, SpitDataImportsWelcomeImportServiceEntry);
#line 386 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = self->priv->discovered_libraries;
#line 386 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0__length1 = self->priv->discovered_libraries_length1;
#line 2714 "DataImportsPluginHost.c"
	{
		SpitDataImportsImportableLibrary** library_collection = NULL;
		gint library_collection_length1 = 0;
		gint _library_collection_size_ = 0;
		gint library_it = 0;
#line 386 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		library_collection = _tmp0_;
#line 386 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		library_collection_length1 = _tmp0__length1;
#line 386 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		for (library_it = 0; library_it < _tmp0__length1; library_it = library_it + 1) {
#line 2726 "DataImportsPluginHost.c"
			SpitDataImportsImportableLibrary* _tmp1_ = NULL;
			SpitDataImportsImportableLibrary* library = NULL;
#line 386 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp1_ = _g_object_ref0 (library_collection[library_it]);
#line 386 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			library = _tmp1_;
#line 2733 "DataImportsPluginHost.c"
			{
				SpitDataImportsPluginHost* _tmp2_ = NULL;
				SpitDataImportsDataImporter* _tmp3_ = NULL;
				SpitDataImportsDataImporter* _tmp4_ = NULL;
				SpitDataImportsImportableLibrary* _tmp5_ = NULL;
#line 387 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp2_ = self->priv->host;
#line 387 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp3_ = spit_data_imports_plugin_host_get_data_importer (_tmp2_);
#line 387 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp4_ = _tmp3_;
#line 387 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp5_ = library;
#line 387 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				spit_data_imports_data_importer_on_library_selected (_tmp4_, _tmp5_);
#line 387 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_g_object_unref0 (_tmp4_);
#line 386 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_g_object_unref0 (library);
#line 2753 "DataImportsPluginHost.c"
			}
		}
	}
}


static void spit_data_imports_welcome_import_service_entry_class_init (SpitDataImportsWelcomeImportServiceEntryClass * klass) {
#line 367 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_welcome_import_service_entry_parent_class = g_type_class_peek_parent (klass);
#line 367 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_type_class_add_private (klass, sizeof (SpitDataImportsWelcomeImportServiceEntryPrivate));
#line 367 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	G_OBJECT_CLASS (klass)->finalize = spit_data_imports_welcome_import_service_entry_finalize;
#line 2767 "DataImportsPluginHost.c"
}


static void spit_data_imports_welcome_import_service_entry_welcome_service_entry_interface_init (WelcomeServiceEntryIface * iface) {
#line 367 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_welcome_import_service_entry_welcome_service_entry_parent_iface = g_type_interface_peek_parent (iface);
#line 367 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->get_service_name = (gchar* (*)(WelcomeServiceEntry*)) spit_data_imports_welcome_import_service_entry_real_get_service_name;
#line 367 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->execute = (void (*)(WelcomeServiceEntry*)) spit_data_imports_welcome_import_service_entry_real_execute;
#line 2778 "DataImportsPluginHost.c"
}


static void spit_data_imports_welcome_import_service_entry_instance_init (SpitDataImportsWelcomeImportServiceEntry * self) {
#line 367 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv = SPIT_DATA_IMPORTS_WELCOME_IMPORT_SERVICE_ENTRY_GET_PRIVATE (self);
#line 2785 "DataImportsPluginHost.c"
}


static void spit_data_imports_welcome_import_service_entry_finalize (GObject* obj) {
	SpitDataImportsWelcomeImportServiceEntry * self;
#line 367 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_SERVICE_ENTRY, SpitDataImportsWelcomeImportServiceEntry);
#line 368 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_free0 (self->priv->pluggable_name);
#line 369 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->discovered_libraries = (_vala_array_free (self->priv->discovered_libraries, self->priv->discovered_libraries_length1, (GDestroyNotify) g_object_unref), NULL);
#line 370 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (self->priv->host);
#line 367 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	G_OBJECT_CLASS (spit_data_imports_welcome_import_service_entry_parent_class)->finalize (obj);
#line 2801 "DataImportsPluginHost.c"
}


GType spit_data_imports_welcome_import_service_entry_get_type (void) {
	static volatile gsize spit_data_imports_welcome_import_service_entry_type_id__volatile = 0;
	if (g_once_init_enter (&spit_data_imports_welcome_import_service_entry_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SpitDataImportsWelcomeImportServiceEntryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) spit_data_imports_welcome_import_service_entry_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SpitDataImportsWelcomeImportServiceEntry), 0, (GInstanceInitFunc) spit_data_imports_welcome_import_service_entry_instance_init, NULL };
		static const GInterfaceInfo welcome_service_entry_info = { (GInterfaceInitFunc) spit_data_imports_welcome_import_service_entry_welcome_service_entry_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType spit_data_imports_welcome_import_service_entry_type_id;
		spit_data_imports_welcome_import_service_entry_type_id = g_type_register_static (G_TYPE_OBJECT, "SpitDataImportsWelcomeImportServiceEntry", &g_define_type_info, 0);
		g_type_add_interface_static (spit_data_imports_welcome_import_service_entry_type_id, TYPE_WELCOME_SERVICE_ENTRY, &welcome_service_entry_info);
		g_once_init_leave (&spit_data_imports_welcome_import_service_entry_type_id__volatile, spit_data_imports_welcome_import_service_entry_type_id);
	}
	return spit_data_imports_welcome_import_service_entry_type_id__volatile;
}


SpitDataImportsWelcomeImportMetaHost* spit_data_imports_welcome_import_meta_host_construct (GType object_type, WelcomeDialog* dialog) {
	SpitDataImportsWelcomeImportMetaHost * self = NULL;
	WelcomeDialog* _tmp0_ = NULL;
	WelcomeDialog* _tmp1_ = NULL;
#line 395 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_val_if_fail (IS_WELCOME_DIALOG (dialog), NULL);
#line 395 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = (SpitDataImportsWelcomeImportMetaHost*) g_object_new (object_type, NULL);
#line 396 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = dialog;
#line 396 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 396 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (self->priv->dialog);
#line 396 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->dialog = _tmp1_;
#line 395 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return self;
#line 2837 "DataImportsPluginHost.c"
}


SpitDataImportsWelcomeImportMetaHost* spit_data_imports_welcome_import_meta_host_new (WelcomeDialog* dialog) {
#line 395 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return spit_data_imports_welcome_import_meta_host_construct (SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_META_HOST, dialog);
#line 2844 "DataImportsPluginHost.c"
}


void spit_data_imports_welcome_import_meta_host_start (SpitDataImportsWelcomeImportMetaHost* self) {
	SpitDataImportsService** services = NULL;
	gint _tmp0_ = 0;
	SpitDataImportsService** _tmp1_ = NULL;
	gint services_length1 = 0;
	gint _services_size_ = 0;
	SpitDataImportsService** _tmp2_ = NULL;
	gint _tmp2__length1 = 0;
#line 399 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (SPIT_DATA_IMPORTS_IS_WELCOME_IMPORT_META_HOST (self));
#line 400 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = spit_data_imports_load_all_services (&_tmp0_);
#line 400 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	services = _tmp1_;
#line 400 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	services_length1 = _tmp0_;
#line 400 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_services_size_ = services_length1;
#line 401 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = services;
#line 401 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2__length1 = services_length1;
#line 2870 "DataImportsPluginHost.c"
	{
		SpitDataImportsService** service_collection = NULL;
		gint service_collection_length1 = 0;
		gint _service_collection_size_ = 0;
		gint service_it = 0;
#line 401 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		service_collection = _tmp2_;
#line 401 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		service_collection_length1 = _tmp2__length1;
#line 401 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		for (service_it = 0; service_it < _tmp2__length1; service_it = service_it + 1) {
#line 2882 "DataImportsPluginHost.c"
			SpitDataImportsService* _tmp3_ = NULL;
			SpitDataImportsService* service = NULL;
#line 401 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp3_ = _g_object_ref0 (service_collection[service_it]);
#line 401 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			service = _tmp3_;
#line 2889 "DataImportsPluginHost.c"
			{
				SpitDataImportsWelcomeDataImportsHost* host = NULL;
				SpitDataImportsService* _tmp4_ = NULL;
				SpitDataImportsWelcomeDataImportsHost* _tmp5_ = NULL;
				SpitDataImportsWelcomeDataImportsHost* _tmp6_ = NULL;
#line 402 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp4_ = service;
#line 402 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp5_ = spit_data_imports_welcome_data_imports_host_new (_tmp4_, self);
#line 402 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				host = _tmp5_;
#line 403 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp6_ = host;
#line 403 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				spit_data_imports_plugin_host_start_importing (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 401 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_g_object_unref0 (host);
#line 401 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_g_object_unref0 (service);
#line 2909 "DataImportsPluginHost.c"
			}
		}
	}
#line 399 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	services = (_vala_array_free (services, services_length1, (GDestroyNotify) g_object_unref), NULL);
#line 2915 "DataImportsPluginHost.c"
}


void spit_data_imports_welcome_import_meta_host_finalize_import (SpitDataImportsWelcomeImportMetaHost* self, SpitDataImportsWelcomeDataImportsHost* host) {
	SpitDataImportsWelcomeDataImportsHost* _tmp0_ = NULL;
#line 407 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (SPIT_DATA_IMPORTS_IS_WELCOME_IMPORT_META_HOST (self));
#line 407 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (SPIT_DATA_IMPORTS_IS_WELCOME_DATA_IMPORTS_HOST (host));
#line 408 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = host;
#line 408 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_plugin_host_stop_importing (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 2929 "DataImportsPluginHost.c"
}


void spit_data_imports_welcome_import_meta_host_install_service_entry (SpitDataImportsWelcomeImportMetaHost* self, WelcomeServiceEntry* entry) {
	WelcomeServiceEntry* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	WelcomeDialog* _tmp5_ = NULL;
	WelcomeServiceEntry* _tmp6_ = NULL;
#line 411 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (SPIT_DATA_IMPORTS_IS_WELCOME_IMPORT_META_HOST (self));
#line 411 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (IS_WELCOME_SERVICE_ENTRY (entry));
#line 412 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = entry;
#line 412 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = welcome_service_entry_get_service_name (_tmp0_);
#line 412 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = _tmp1_;
#line 412 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp3_ = g_strdup_printf ("WelcomeImportMetaHost: Installing service entry for %s", _tmp2_);
#line 412 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp4_ = _tmp3_;
#line 412 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_debug ("DataImportsPluginHost.vala:412: %s", _tmp4_);
#line 412 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_free0 (_tmp4_);
#line 412 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_free0 (_tmp2_);
#line 413 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp5_ = self->priv->dialog;
#line 413 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp6_ = entry;
#line 413 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	welcome_dialog_install_service_entry (_tmp5_, _tmp6_);
#line 2967 "DataImportsPluginHost.c"
}


static void spit_data_imports_welcome_import_meta_host_class_init (SpitDataImportsWelcomeImportMetaHostClass * klass) {
#line 392 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_welcome_import_meta_host_parent_class = g_type_class_peek_parent (klass);
#line 392 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_type_class_add_private (klass, sizeof (SpitDataImportsWelcomeImportMetaHostPrivate));
#line 392 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	G_OBJECT_CLASS (klass)->finalize = spit_data_imports_welcome_import_meta_host_finalize;
#line 2978 "DataImportsPluginHost.c"
}


static void spit_data_imports_welcome_import_meta_host_instance_init (SpitDataImportsWelcomeImportMetaHost * self) {
#line 392 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv = SPIT_DATA_IMPORTS_WELCOME_IMPORT_META_HOST_GET_PRIVATE (self);
#line 2985 "DataImportsPluginHost.c"
}


static void spit_data_imports_welcome_import_meta_host_finalize (GObject* obj) {
	SpitDataImportsWelcomeImportMetaHost * self;
#line 392 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_META_HOST, SpitDataImportsWelcomeImportMetaHost);
#line 393 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (self->priv->dialog);
#line 392 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	G_OBJECT_CLASS (spit_data_imports_welcome_import_meta_host_parent_class)->finalize (obj);
#line 2997 "DataImportsPluginHost.c"
}


GType spit_data_imports_welcome_import_meta_host_get_type (void) {
	static volatile gsize spit_data_imports_welcome_import_meta_host_type_id__volatile = 0;
	if (g_once_init_enter (&spit_data_imports_welcome_import_meta_host_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SpitDataImportsWelcomeImportMetaHostClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) spit_data_imports_welcome_import_meta_host_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SpitDataImportsWelcomeImportMetaHost), 0, (GInstanceInitFunc) spit_data_imports_welcome_import_meta_host_instance_init, NULL };
		GType spit_data_imports_welcome_import_meta_host_type_id;
		spit_data_imports_welcome_import_meta_host_type_id = g_type_register_static (G_TYPE_OBJECT, "SpitDataImportsWelcomeImportMetaHost", &g_define_type_info, 0);
		g_once_init_leave (&spit_data_imports_welcome_import_meta_host_type_id__volatile, spit_data_imports_welcome_import_meta_host_type_id);
	}
	return spit_data_imports_welcome_import_meta_host_type_id__volatile;
}


SpitDataImportsService** spit_data_imports_load_all_services (int* result_length1) {
	SpitDataImportsService** result = NULL;
	gint _tmp0_ = 0;
	SpitDataImportsService** _tmp1_ = NULL;
	SpitDataImportsService** _tmp2_ = NULL;
	gint _tmp2__length1 = 0;
#line 418 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = spit_data_imports_load_services (TRUE, &_tmp0_);
#line 418 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = _tmp1_;
#line 418 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2__length1 = _tmp0_;
#line 418 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (result_length1) {
#line 418 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		*result_length1 = _tmp2__length1;
#line 3029 "DataImportsPluginHost.c"
	}
#line 418 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	result = _tmp2_;
#line 418 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return result;
#line 3035 "DataImportsPluginHost.c"
}


static void _vala_array_add151 (SpitDataImportsService*** array, int* length, int* size, SpitDataImportsService* value) {
#line 447 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if ((*length) == (*size)) {
#line 447 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 447 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		*array = g_renew (SpitDataImportsService*, *array, (*size) + 1);
#line 3046 "DataImportsPluginHost.c"
	}
#line 447 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	(*array)[(*length)++] = value;
#line 447 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	(*array)[*length] = NULL;
#line 3052 "DataImportsPluginHost.c"
}


static gint __lambda21_ (void* a, void* b) {
	gint result = 0;
	void* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	void* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gint _tmp4_ = 0;
#line 453 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = a;
#line 453 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = spit_pluggable_get_pluggable_name (G_TYPE_CHECK_INSTANCE_CAST (*((SpitDataImportsService**) _tmp0_), SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 453 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = b;
#line 453 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp3_ = spit_pluggable_get_pluggable_name (G_TYPE_CHECK_INSTANCE_CAST (*((SpitDataImportsService**) _tmp2_), SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 453 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp4_ = utf8_cs_compare (_tmp1_, _tmp3_);
#line 453 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	result = _tmp4_;
#line 453 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return result;
#line 3077 "DataImportsPluginHost.c"
}


static gint ___lambda21____compar_fn_t (void* key1, void* key2) {
	gint result;
	result = __lambda21_ (key1, key2);
#line 452 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return result;
#line 3086 "DataImportsPluginHost.c"
}


SpitDataImportsService** spit_data_imports_load_services (gboolean load_all, int* result_length1) {
	SpitDataImportsService** result = NULL;
	SpitDataImportsService** loaded_services = NULL;
	SpitDataImportsService** _tmp0_ = NULL;
	gint loaded_services_length1 = 0;
	gint _loaded_services_size_ = 0;
	GeeCollection* pluggables = NULL;
	gboolean _tmp1_ = FALSE;
	GeeCollection* _tmp2_ = NULL;
	GeeCollection* _tmp3_ = NULL;
	gint _tmp4_ = 0;
	gint _tmp5_ = 0;
	SpitDataImportsService** _tmp26_ = NULL;
	gint _tmp26__length1 = 0;
	SpitDataImportsService** _tmp27_ = NULL;
	gint _tmp27__length1 = 0;
	SpitDataImportsService** _tmp28_ = NULL;
	gint _tmp28__length1 = 0;
#line 422 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = g_new0 (SpitDataImportsService*, 0 + 1);
#line 422 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	loaded_services = _tmp0_;
#line 422 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	loaded_services_length1 = 0;
#line 422 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_loaded_services_size_ = loaded_services_length1;
#line 425 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = load_all;
#line 425 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = plugins_get_pluggables_for_type (SPIT_DATA_IMPORTS_TYPE_SERVICE, NULL, NULL, NULL, _tmp1_);
#line 425 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	pluggables = _tmp2_;
#line 429 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp3_ = pluggables;
#line 429 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp4_ = gee_collection_get_size (_tmp3_);
#line 429 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp5_ = _tmp4_;
#line 429 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_debug ("DataImportsPluginHost.vala:429: DataImportsDialog: discovered %d plugg" \
"able data import services.", _tmp5_);
#line 3130 "DataImportsPluginHost.c"
	{
		GeeIterator* _pluggable_it = NULL;
		GeeCollection* _tmp6_ = NULL;
		GeeIterator* _tmp7_ = NULL;
#line 431 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp6_ = pluggables;
#line 431 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp7_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GEE_TYPE_ITERABLE, GeeIterable));
#line 431 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_pluggable_it = _tmp7_;
#line 431 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		while (TRUE) {
#line 3143 "DataImportsPluginHost.c"
			GeeIterator* _tmp8_ = NULL;
			gboolean _tmp9_ = FALSE;
			SpitPluggable* pluggable = NULL;
			GeeIterator* _tmp10_ = NULL;
			gpointer _tmp11_ = NULL;
			gint pluggable_interface = 0;
			SpitPluggable* _tmp12_ = NULL;
			gint _tmp13_ = 0;
			gint _tmp14_ = 0;
			SpitDataImportsService* service = NULL;
			SpitPluggable* _tmp19_ = NULL;
			SpitDataImportsService* _tmp20_ = NULL;
			SpitDataImportsService* _tmp21_ = NULL;
			const gchar* _tmp22_ = NULL;
			SpitDataImportsService** _tmp23_ = NULL;
			gint _tmp23__length1 = 0;
			SpitDataImportsService* _tmp24_ = NULL;
			SpitDataImportsService* _tmp25_ = NULL;
#line 431 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp8_ = _pluggable_it;
#line 431 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp9_ = gee_iterator_next (_tmp8_);
#line 431 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			if (!_tmp9_) {
#line 431 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				break;
#line 3170 "DataImportsPluginHost.c"
			}
#line 431 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp10_ = _pluggable_it;
#line 431 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp11_ = gee_iterator_get (_tmp10_);
#line 431 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			pluggable = (SpitPluggable*) _tmp11_;
#line 432 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp12_ = pluggable;
#line 432 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp13_ = spit_pluggable_get_pluggable_interface (_tmp12_, SPIT_DATA_IMPORTS_CURRENT_INTERFACE, SPIT_DATA_IMPORTS_CURRENT_INTERFACE);
#line 432 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			pluggable_interface = _tmp13_;
#line 434 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp14_ = pluggable_interface;
#line 434 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			if (_tmp14_ != SPIT_DATA_IMPORTS_CURRENT_INTERFACE) {
#line 3188 "DataImportsPluginHost.c"
				SpitPluggable* _tmp15_ = NULL;
				gchar* _tmp16_ = NULL;
				gchar* _tmp17_ = NULL;
				gint _tmp18_ = 0;
#line 435 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp15_ = pluggable;
#line 435 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp16_ = plugins_get_pluggable_module_id (_tmp15_);
#line 435 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp17_ = _tmp16_;
#line 435 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp18_ = pluggable_interface;
#line 435 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				g_warning ("DataImportsPluginHost.vala:435: Unable to load data import plugin %s: " \
"reported interface %d.", _tmp17_, _tmp18_);
#line 435 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_g_free0 (_tmp17_);
#line 438 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_g_object_unref0 (pluggable);
#line 438 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				continue;
#line 3209 "DataImportsPluginHost.c"
			}
#line 441 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp19_ = pluggable;
#line 441 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp20_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, SPIT_DATA_IMPORTS_TYPE_SERVICE, SpitDataImportsService));
#line 441 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			service = _tmp20_;
#line 444 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp21_ = service;
#line 444 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp22_ = spit_pluggable_get_pluggable_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 444 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			g_debug ("DataImportsPluginHost.vala:444: DataImportsDialog: discovered pluggabl" \
"e data import service '%s'.", _tmp22_);
#line 447 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp23_ = loaded_services;
#line 447 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp23__length1 = loaded_services_length1;
#line 447 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp24_ = service;
#line 447 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp25_ = _g_object_ref0 (_tmp24_);
#line 447 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_vala_array_add151 (&loaded_services, &loaded_services_length1, &_loaded_services_size_, _tmp25_);
#line 431 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_g_object_unref0 (service);
#line 431 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_g_object_unref0 (pluggable);
#line 3237 "DataImportsPluginHost.c"
		}
#line 431 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_g_object_unref0 (_pluggable_it);
#line 3241 "DataImportsPluginHost.c"
	}
#line 452 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp26_ = loaded_services;
#line 452 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp26__length1 = loaded_services_length1;
#line 452 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp27_ = loaded_services;
#line 452 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp27__length1 = loaded_services_length1;
#line 452 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	qsort (_tmp26_, (gsize) _tmp27__length1, (gsize) sizeof (SpitDataImportsService*), ___lambda21____compar_fn_t);
#line 457 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp28_ = loaded_services;
#line 457 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp28__length1 = loaded_services_length1;
#line 457 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (result_length1) {
#line 457 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		*result_length1 = _tmp28__length1;
#line 3261 "DataImportsPluginHost.c"
	}
#line 457 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	result = _tmp28_;
#line 457 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (pluggables);
#line 457 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return result;
#line 3269 "DataImportsPluginHost.c"
}


void spit_data_imports_data_import_reporter (ImportManifest* manifest, BatchImportRoll* import_roll) {
	ImportManifest* _tmp0_ = NULL;
	GeeList* _tmp1_ = NULL;
	gint _tmp2_ = 0;
	gint _tmp3_ = 0;
#line 462 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (IS_IMPORT_MANIFEST (manifest));
#line 462 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (IS_BATCH_IMPORT_ROLL (import_roll));
#line 463 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = manifest;
#line 463 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = _tmp0_->all;
#line 463 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GEE_TYPE_COLLECTION, GeeCollection));
#line 463 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp3_ = _tmp2_;
#line 463 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (_tmp3_ > 0) {
#line 3292 "DataImportsPluginHost.c"
		ImportManifest* _tmp4_ = NULL;
#line 464 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp4_ = spit_data_imports_meta_manifest;
#line 464 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		if (_tmp4_ == NULL) {
#line 3298 "DataImportsPluginHost.c"
			ImportManifest* _tmp5_ = NULL;
#line 465 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp5_ = import_manifest_new (NULL, NULL);
#line 465 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_import_manifest_unref0 (spit_data_imports_meta_manifest);
#line 465 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			spit_data_imports_meta_manifest = _tmp5_;
#line 3306 "DataImportsPluginHost.c"
		}
		{
			GeeList* _result_list = NULL;
			ImportManifest* _tmp6_ = NULL;
			GeeList* _tmp7_ = NULL;
			GeeList* _tmp8_ = NULL;
			gint _result_size = 0;
			GeeList* _tmp9_ = NULL;
			gint _tmp10_ = 0;
			gint _tmp11_ = 0;
			gint _result_index = 0;
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp6_ = manifest;
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp7_ = _tmp6_->all;
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp8_ = _g_object_ref0 (_tmp7_);
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_result_list = _tmp8_;
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp9_ = _result_list;
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp10_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, GEE_TYPE_COLLECTION, GeeCollection));
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp11_ = _tmp10_;
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_result_size = _tmp11_;
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_result_index = -1;
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			while (TRUE) {
#line 3338 "DataImportsPluginHost.c"
				gint _tmp12_ = 0;
				gint _tmp13_ = 0;
				gint _tmp14_ = 0;
				BatchImportResult* _result_ = NULL;
				GeeList* _tmp15_ = NULL;
				gint _tmp16_ = 0;
				gpointer _tmp17_ = NULL;
				ImportManifest* _tmp18_ = NULL;
				BatchImportResult* _tmp19_ = NULL;
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp12_ = _result_index;
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_result_index = _tmp12_ + 1;
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp13_ = _result_index;
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp14_ = _result_size;
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				if (!(_tmp13_ < _tmp14_)) {
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					break;
#line 3360 "DataImportsPluginHost.c"
				}
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp15_ = _result_list;
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp16_ = _result_index;
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp17_ = gee_list_get (_tmp15_, _tmp16_);
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_result_ = (BatchImportResult*) _tmp17_;
#line 467 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp18_ = spit_data_imports_meta_manifest;
#line 467 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp19_ = _result_;
#line 467 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				import_manifest_add_result (_tmp18_, _tmp19_);
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_batch_import_result_unref0 (_result_);
#line 3378 "DataImportsPluginHost.c"
			}
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_g_object_unref0 (_result_list);
#line 3382 "DataImportsPluginHost.c"
		}
	} else {
		ImportManifest* _tmp20_ = NULL;
#line 470 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		data_imports_ui_data_imports_dialog_terminate_instance ();
#line 471 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp20_ = spit_data_imports_meta_manifest;
#line 471 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		import_ui_report_manifest (_tmp20_, TRUE, NULL);
#line 472 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_import_manifest_unref0 (spit_data_imports_meta_manifest);
#line 472 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		spit_data_imports_meta_manifest = NULL;
#line 3396 "DataImportsPluginHost.c"
	}
}


gint64 spit_data_imports_import_job_comparator (void* a, void* b) {
	gint64 result = 0LL;
	void* _tmp0_ = NULL;
	time_t _tmp1_ = 0;
	void* _tmp2_ = NULL;
	time_t _tmp3_ = 0;
#line 477 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = a;
#line 477 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = spit_data_imports_data_import_job_get_exposure_time (G_TYPE_CHECK_INSTANCE_CAST ((SpitDataImportsDataImportJob*) _tmp0_, SPIT_DATA_IMPORTS_TYPE_DATA_IMPORT_JOB, SpitDataImportsDataImportJob));
#line 477 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = b;
#line 477 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp3_ = spit_data_imports_data_import_job_get_exposure_time (G_TYPE_CHECK_INSTANCE_CAST ((SpitDataImportsDataImportJob*) _tmp2_, SPIT_DATA_IMPORTS_TYPE_DATA_IMPORT_JOB, SpitDataImportsDataImportJob));
#line 477 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	result = (gint64) (_tmp1_ - _tmp3_);
#line 477 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return result;
#line 3419 "DataImportsPluginHost.c"
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



